<?php

/*
Plugin Name: Events Optimizer
Plugin URI: https://www.heinrich.biz
Description: Automatically identify invalid event, venue and organizer data and optimize it. Add events automatically. Requires The Events Calendar Plugin.
Version: 0.80
Author: Oliver Heinrich
Author URI: https://www.heinrich.biz
Text Domain: events-optimizer
Domain Path: /languages
*/
//----------------------------------------------------------------------------------------
// Load Freemius SDK
// https://www.freemius.com
//----------------------------------------------------------------------------------------

if ( !function_exists( 'teo_fs' ) ) {
    // Create a helper function for easy SDK access.
    function teo_fs()
    {
        global  $teo_fs ;
        
        if ( !isset( $teo_fs ) ) {
            // Include Freemius SDK.
            require_once dirname( __FILE__ ) . '/freemius/start.php';
            
            if ( is_plugin_active( 'the-events-calendar/the-events-calendar.php' ) ) {
                $teo_fs = fs_dynamic_init( array(
                    'id'             => '8391',
                    'slug'           => 'events-optimizer',
                    'premium_slug'   => 'events-optimizer-pro',
                    'type'           => 'plugin',
                    'public_key'     => 'pk_94f588954e6ff1b7a22a3734cae8a',
                    'is_premium'     => false,
                    'premium_suffix' => '(Pro)',
                    'has_addons'     => false,
                    'has_paid_plans' => true,
                    'menu'           => array(
                    'slug'           => 'events_optimizer',
                    'override_exact' => true,
                    'first-path'     => 'edit.php?post_type=tribe_events&page=events_optimizer&tab=tab-4',
                    'support'        => false,
                    'parent'         => array(
                    'slug' => 'edit.php?post_type=tribe_events',
                ),
                ),
                    'is_live'        => true,
                ) );
            } else {
                update_option( 'teo_tec_installed_notice', false );
                $teo_fs = fs_dynamic_init( array(
                    'id'             => '8391',
                    'slug'           => 'events-optimizer',
                    'premium_slug'   => 'events-optimizer-pro',
                    'type'           => 'plugin',
                    'public_key'     => 'pk_94f588954e6ff1b7a22a3734cae8a',
                    'is_premium'     => false,
                    'premium_suffix' => '(Pro)',
                    'has_addons'     => false,
                    'has_paid_plans' => true,
                    'menu'           => array(
                    'slug'           => 'events_optimizer',
                    'override_exact' => true,
                    'first-path'     => 'plugins.php',
                    'support'        => false,
                    'parent'         => array(
                    'slug' => 'edit.php?post_type=tribe_events',
                ),
                ),
                    'is_live'        => true,
                ) );
            }
        
        }
        
        return $teo_fs;
    }
    
    // Init Freemius.
    teo_fs();
    // Signal that SDK was initiated.
    do_action( 'teo_fs_loaded' );
    function teo_fs_settings_url()
    {
        return admin_url( 'edit.php?post_type=tribe_events&page=events_optimizer&tab=tab-4' );
    }
    
    teo_fs()->add_filter( 'connect_url', 'teo_fs_settings_url' );
    teo_fs()->add_filter( 'after_skip_url', 'teo_fs_settings_url' );
    teo_fs()->add_filter( 'after_connect_url', 'teo_fs_settings_url' );
    teo_fs()->add_filter( 'after_pending_connect_url', 'teo_fs_settings_url' );
}

//----------------------------------------------------------------------------------------
// Load translations
//----------------------------------------------------------------------------------------
add_action( 'plugins_loaded', 'teo_load_plugin_textdomain' );
function teo_load_plugin_textdomain()
{
    load_plugin_textdomain( 'events-optimizer', false, basename( dirname( __FILE__ ) ) . '/languages/' );
}

//----------------------------------------------------------------------------------------
// Initialize menu and settings
//----------------------------------------------------------------------------------------
// Add Optimizer to Events Calendar menu in WordPress dashboard
add_action( 'admin_menu', 'teo_initialize_menu' );
function teo_initialize_menu()
{
    // Add Menu to Events Calendar
    $my_page = add_submenu_page(
        'edit.php?post_type=tribe_events',
        'Events Optimizer',
        'Optimizer',
        'administrator',
        'events_optimizer',
        'events_optimizer_menu'
    );
    // Call register settings function
    add_action( 'admin_init', 'teo_register_settings' );
    // Load the JS conditionally (see next function below)
    add_action( 'load-' . $my_page, 'teo_load_admin_js' );
}

//----------------------------------------------------------------------------------------
// This function is only called when the Event Optimizers page is loaded
// https://wordpress.stackexchange.com/questions/41207/how-do-i-enqueue-styles-scripts-on-certain-wp-admin-pages
//----------------------------------------------------------------------------------------
function teo_load_admin_js()
{
    // Unfortunately the scripts can't enqueued here - it's too early. So register against the proper action hook to do it
    add_action( 'admin_enqueue_scripts', 'teo_enqueue_admin_js' );
}

//----------------------------------------------------------------------------------------
// Include CSS and JavaScript files
//----------------------------------------------------------------------------------------
function teo_enqueue_admin_js()
{
    // Load the scripts that have been registered above
    wp_enqueue_script( 'tabs.js', plugin_dir_url( __FILE__ ) . 'js/tabs.js' );
    wp_enqueue_style( 'style.css', plugin_dir_url( __FILE__ ) . 'css/style.css' );
}

//----------------------------------------------------------------------------------------
// Register settings
//----------------------------------------------------------------------------------------
function teo_register_settings()
{
    register_setting( 'events-optimizer-settings', 'teo_max_results_per_page' );
    //register_setting( 'events-optimizer-settings', 'teo_remove_settings' );
    // Set default values
    if ( !get_option( 'teo_max_results_per_page' ) ) {
        update_option( 'teo_max_results_per_page', 5 );
    }
    // endif teo_fs()->can_use_premium_code__premium_only()
}

//----------------------------------------------------------------------------------------
// Messages to show in WordPress Dashboard
//----------------------------------------------------------------------------------------
if ( get_option( 'teo_update_notice' ) != true ) {
    add_action( 'admin_notices', 'teo_admin_notice' );
}
function teo_admin_notice()
{
    // Check if The Events Calendar plugin is installed and active
    
    if ( is_plugin_active( 'the-events-calendar/the-events-calendar.php' ) ) {
        // Show infos about the latest update
        ?><div class="notice notice-success teo-update-notice is-dismissible">
			<p>
			<?php 
        \esc_html_e( 'With this new version you can add events automatically from Google Events. Check out the', 'events-optimizer' );
        ?> 
			<a href="/wp-admin/edit.php?post_type=tribe_events&page=events_optimizer&tab=tab-4">
			<?php 
        \esc_html_e( 'Events Optimizer settings.', 'events-optimizer' );
        ?>
			</a>
			</p>			
		</div><?php 
    }

}

if ( get_option( 'teo_tec_installed_notice' ) != true ) {
    add_action( 'admin_notices', 'tec_admin_tec_installed_notice' );
}
function tec_admin_tec_installed_notice()
{
    // Check if The Events Calendar plugin is installed and active
    
    if ( is_plugin_active( 'the-events-calendar/the-events-calendar.php' ) ) {
        ?><div class="notice notice-success teo-tec-installed-notice is-dismissible">
			<p>
			<?php 
        \esc_html_e( 'Events Optimizer installation successful. Before using it please create a backup of your website and be sure to review the ', 'events-optimizer' );
        ?>
			<a href="/wp-admin/edit.php?post_type=tribe_events&page=events_optimizer&tab=tab-4">
			<?php 
        \esc_html_e( 'Events Optimizer settings.', 'events-optimizer' );
        ?>
			</a>
			</p>			
		</div><?php 
    } else {
        ?><div class="notice notice-error teo-tec-installed-notice">
			<p>
			<?php 
        \esc_html_e( 'The Events Calendar Plugin is not activated! Please install and activate it before using the Events Optimizer!', 'events-optimizer' );
        ?>
			</p>			
		</div><?php 
    }

}

//----------------------------------------------------------------------------------------
// Enque script for admin notices
//----------------------------------------------------------------------------------------
add_action( 'admin_enqueue_scripts', 'add_script' );
function add_script()
{
    wp_register_script(
        'notice-update',
        plugin_dir_url( __FILE__ ) . 'js/notice-update.js',
        '',
        '1.0',
        false
    );
    wp_localize_script( 'notice-update', 'notice_params', array(
        'ajaxurl' => get_admin_url() . 'admin-ajax.php',
    ) );
    wp_enqueue_script( 'notice-update' );
}

//----------------------------------------------------------------------------------------
// If notices are dismissed don't show it again
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_my_dismiss_notice', 'my_dismiss_notice' );
function my_dismiss_notice()
{
    update_option( 'teo_update_notice', true );
}

add_action( 'wp_ajax_my_dismiss_notice_tec_installed', 'my_dismiss_notice_tec_installed' );
function my_dismiss_notice_tec_installed()
{
    update_option( 'teo_tec_installed_notice', true );
}

//----------------------------------------------------------------------------------------
// Main function: Create Menu / Tabs
//----------------------------------------------------------------------------------------
function events_optimizer_menu()
{
    // Check if user has admin permissions
    if ( !current_user_can( 'manage_options' ) ) {
        wp_die( __( 'You are not authorized to view this page!', 'events-optimizer' ) );
    }
    // Get settings
    $max_results_per_page = get_option( 'teo_max_results_per_page' );
    $phone_number_format = get_option( 'teo_phone_number_format' );
    $address_format = get_option( 'teo_address_format' );
    $preselection = get_option( 'teo_preselection' );
    $nonce = wp_create_nonce( 'events-optimizer-nonce' );
    // Create submenu
    ?>
	<div class='wrap'>	
		<h1 class="wp-heading-inline"><?php 
    _e( 'Events Optimizer', 'events-optimizer' );
    ?></h1>
	
		<?php 
    $active_tab = $_GET['tab'] ?? '';
    ?>

		<!-- Setup Tabs -->
		<!-- // https://epiph.yt/blog/2018/einfache-javascript-tabs-im-wordpress-backend/ -->
		<h2 class="nav-tab-wrapper">
			<a href="edit.php?post_type=tribe_events&page=events_optimizer&tab=tab-1" class="nav-tab<?php 
    echo  ( $active_tab === 'tab-1' || empty($active_tab) ? ' nav-tab-active' : '' ) ;
    ?>" data-slug= 'tab-1' ><?php 
    \esc_html_e( 'Venues', 'events-optimizer' );
    ?></a>
			<a href="edit.php?post_type=tribe_events&page=events_optimizer&tab=tab-2" class="nav-tab<?php 
    echo  ( $active_tab === 'tab-2' ? ' nav-tab-active' : '' ) ;
    ?>" data-slug= 'tab-2' ><?php 
    \esc_html_e( 'Organizers', 'events-optimizer' );
    ?></a>
			<a href="edit.php?post_type=tribe_events&page=events_optimizer&tab=tab-3" class="nav-tab<?php 
    echo  ( $active_tab === 'tab-3' ? ' nav-tab-active' : '' ) ;
    ?>" data-slug= 'tab-3' ><?php 
    \esc_html_e( 'Events', 'events-optimizer' );
    ?></a>
			<a href="edit.php?post_type=tribe_events&page=events_optimizer&tab=tab-4" class="nav-tab<?php 
    echo  ( $active_tab === 'tab-4' ? ' nav-tab-active' : '' ) ;
    ?>" data-slug= 'tab-4' ><?php 
    \esc_html_e( 'Settings', 'events-optimizer' );
    ?></a>
		</h2>
		

		<!-- Add Venues content to tabs -->
		<div class="nav-tab-content<?php 
    echo  ( $active_tab === 'tab-1' || empty($active_tab) ? ' nav-tab-content-active' : '' ) ;
    ?>" id="nav-tab-content-tab-1">
			<p><?php 
    \esc_html_e( 'Select the data you want to analyze. Duplicate venues can take a long time, please be patient.', 'events-optimizer' );
    ?></p>

			<div class='wrap'>
				<form action='' method='POST' id='venues_form'>				
					<input type='button' name='action' class='button' id='venues_with_invalid_data' value='<?php 
    _e( 'Venues with invalid data', 'events-optimizer' );
    ?>' />&nbsp;&nbsp;&nbsp;
					<input type='button' name='action' class='button' id='duplicate_venues' value='<?php 
    _e( 'Duplicate venues', 'events-optimizer' );
    ?>' <?php 
    echo  "disabled" ;
    ?>  />&nbsp;&nbsp;&nbsp; 
					<input type='button' name='action' class='button' id='venues_google_places_optimization' value='<?php 
    _e( 'Optimization with Google Places', 'events-optimizer' );
    ?>' <?php 
    echo  "disabled" ;
    ?>/>&nbsp;&nbsp;&nbsp;  
				</form>
				<p>
				<div id='show_results_venues'></div>
				<div id='loading_tab_venues'><?php 
    \esc_attr_e( 'ANALYZING', 'events-optimizer' );
    ?></div>
				</p>
			</div>		
		</div>
		

		<!-- Add Organizers content to tabs -->
		<div class="nav-tab-content<?php 
    echo  ( $active_tab === 'tab-2' ? ' nav-tab-content-active' : '' ) ;
    ?>" id="nav-tab-content-tab-2">
			<p><?php 
    \esc_html_e( 'Select the data you want to analyze. Duplicate organizers can take a long time, please be patient.', 'events-optimizer' );
    ?></p>

			<div class='wrap'>
				<form action='' method='POST' id='organizers_form'>
					<input type='button' name='action' class='button' id='organizers_with_invalid_data' value='<?php 
    _e( 'Organizers with invalid data', 'events-optimizer' );
    ?>' />&nbsp;&nbsp;&nbsp;
					<input type='button' name='action' class='button' id='duplicate_organizers' value='<?php 
    _e( 'Duplicate organizers', 'events-optimizer' );
    ?>' <?php 
    echo  "disabled" ;
    ?>  />&nbsp;&nbsp;&nbsp; 
					<input type='button' name='action' class='button' id='organizers_google_places_optimization' value='<?php 
    _e( 'Optimization with Google Places', 'events-optimizer' );
    ?>' <?php 
    echo  "disabled" ;
    ?> />&nbsp;&nbsp;&nbsp;  
				</form>
				<p>
				<div id='show_results_organizers'></div>
				<div id='loading_tab_organizers'><?php 
    \esc_attr_e( 'ANALYZING', 'events-optimizer' );
    ?></div>
				</p>
			</div>			
		</div>
		
		
		<!-- Add Events content to tabs -->
		<div class="nav-tab-content<?php 
    echo  ( $active_tab === 'tab-3' ? ' nav-tab-content-active' : '' ) ;
    ?>" id="nav-tab-content-tab-3">
			<p><?php 
    \esc_html_e( 'Select the data you want to analyze or add. Be aware that adding events is a 2-step approach.', 'events-optimizer' );
    ?></p>

			<div class='wrap'>
				<form action='' method='POST' id='events_form'>
					<span class='frame_around'>
						<input type='button' name='action' class='button' id='events_with_invalid_data' value='<?php 
    _e( 'Events with invalid data', 'events-optimizer' );
    ?>'/>
					</span>
					<span class='frame_around'>
						<?php 
    \esc_html_e( 'Keyword', 'events-optimizer' );
    ?> <input type="text" name="dataforseo_keyword" id="dataforseo_keyword" size="14" value="<?php 
    echo  esc_attr( get_option( 'teo_dataforseo_keyword' ) ) ;
    ?>"<?php 
    echo  "disabled" ;
    ?> />&nbsp;&nbsp;&nbsp;
						<?php 
    \esc_html_e( 'Max. results', 'events-optimizer' );
    ?> <input type="text" name="dataforseo_depth" id="dataforseo_depth" size="2" value="<?php 
    echo  esc_attr( get_option( 'teo_dataforseo_depth' ) ) ;
    ?>"  <?php 
    echo  "disabled" ;
    ?> />&nbsp;&nbsp;
						<input type='button' name='action' class='button' id='search_events_with_google_data' value='<?php 
    _e( 'Search for events', 'events-optimizer' );
    ?>' <?php 
    echo  "disabled" ;
    ?>/>&nbsp;&nbsp;&nbsp;&#10132;&nbsp;&nbsp;&nbsp;<input type='button' name='action' class='button' id='add_events_with_google_data' value='<?php 
    _e( 'Show results', 'events-optimizer' );
    ?>' <?php 
    echo  "disabled" ;
    ?>/>
						<span class='beta_version'>BETA</span>
					</span>
				</form>
				<p>
				<div id='show_results_events'></div>
				<div id='loading_tab_events'><?php 
    \esc_attr_e( 'ANALYZING', 'events-optimizer' );
    ?></div>
				</p>
			</div>			
		</div>	

			
		<!-- Add Settings content to tabs -->
		<div class="nav-tab-content<?php 
    echo  ( $active_tab === 'tab-4' ? ' nav-tab-content-active' : '' ) ;
    ?>" id="nav-tab-content-tab-4">
			<div>
			
				<form action='' method='POST' id='settings_form'>

					<div class="tribe-settings-form-wrap">
						<br><h3><?php 
    \esc_html_e( 'General', 'events-optimizer' );
    ?></h3>
						<?php 
    ?>
						<div id="modern-tribe-info"><?php 
    \esc_html_e( 'Upgrade to Events Optimizer Pro! Enjoy amazing features like finding duplicate venues or organizers, auto completion of venue and organizer data via Google Places. And change all settings that are greyed out! Get more information at ', 'events-optimizer' );
    ?>
							<a href="https://www.heinrich.biz" target="_blank">
							<?php 
    \esc_html_e( 'our website!', 'events-optimizer' );
    ?>
							</a>
						</div>
						<?php 
    ?>						
					
						<table class="form-table">
							<?php 
    ?>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Events Optimizer Pro Licence Key', 'events-optimizer' );
    ?></th>
							<td><a href="https://checkout.freemius.com/mode/dialog/plugin/8391/plan/13936/" class="button-primary" target="_blank"><?php 
    \esc_attr_e( 'Get licence key', 'events-optimizer' );
    ?></a></td>
							</tr>
							<?php 
    ?>						
		
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Maximum results per page', 'events-optimizer' );
    ?></th>
							<td><input type="text" name="max_results_per_page" id="max_results_per_page" size="5" value="<?php 
    echo  esc_attr( get_option( 'teo_max_results_per_page' ) ) ;
    ?>"/>
								<?php 
    \esc_html_e( '(max = 20 to avoid time-outs)', 'events-optimizer' );
    ?></td>
							</tr>
							<!--
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Remove settings during uninstall?', 'events-optimizer' );
    ?> </th>
							<td><input type="checkbox" name="remove_settings" id="remove_settings" value="1" <?php 
    checked( get_option( 'teo_remove_settings' ), 1 );
    ?>/></td>
							</tr>
							-->
						</table>
			
						<br><h3><?php 
    \esc_html_e( 'Duplicate venues / organizers', 'events-optimizer' );
    ?></h3>				
						<div id="modern-tribe-info">
							<?php 
    \esc_html_e( 'With the compare value you can control how identical objects are found. The smaller the value the more identical both objects need to be.', 'events-optimizer' );
    ?><br>
							<li><?php 
    \esc_html_e( 'For venues the name, the address and the first three characters of the ZIP will be used to find identical venues.', 'events-optimizer' );
    ?></li>
							<li><?php 
    \esc_html_e( 'For organizers only the name will be used to find identical organizers.', 'events-optimizer' );
    ?></li>				
						</div>
						<table class="form-table">	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Duplicate organizers compare value', 'events-optimizer' );
    ?></th>
							<td><input type="text" name="duplicate_organizers_levenshtein" id="duplicate_organizers_levenshtein" size="5" value="<?php 
    echo  esc_attr( get_option( 'teo_duplicate_organizers_levenshtein' ) ) ;
    ?>"  <?php 
    echo  "disabled" ;
    ?> />
								<?php 
    \esc_html_e( '(0 = exact match, recommended = 0.15 - 0.3)', 'events-optimizer' );
    ?>
							</td>
							</tr>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Duplicate venues compare value', 'events-optimizer' );
    ?></th>
							<td><input type="text" name="duplicate_venues_levenshtein" id="duplicate_venues_levenshtein" size="5" value="<?php 
    echo  esc_attr( get_option( 'teo_duplicate_venues_levenshtein' ) ) ;
    ?>"  <?php 
    echo  "disabled" ;
    ?> />
								<?php 
    \esc_html_e( '(0 = exact match, recommended = 0.35)', 'events-optimizer' );
    ?>
							</td>
							</tr>
						</table>

						<br><h3><?php 
    \esc_html_e( 'Security', 'events-optimizer' );
    ?></h3>				
						<div id="modern-tribe-info">												
							<li><?php 
    \esc_html_e( 'The Google Safe Browsing technology offers a way to vaildate if a website is not safe possibly', 'events-optimizer' );
    ?> 
							<?php 
    \esc_html_e( '(learn more about in the', 'events-optimizer' );
    ?> <a href="https://transparencyreport.google.com/safe-browsing/overview" target="_blank">Googles Transparency Report).</a>
							<?php 
    \esc_html_e( 'By enabling this option the URLs of venues, organizers and events will be verified.', 'events-optimizer' );
    ?>
							<?php 
    \esc_html_e( 'This can slightly slow down the analysis process.', 'events-optimizer' );
    ?><br></li>
							<li><?php 
    \esc_html_e( 'Check if URLs have missing https / http or are redirected / permanently moved.', 'events-optimizer' );
    ?></li>
						</div>
						<table class="form-table">	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Verify URLs with Google Safe Browsing', 'events-optimizer' );
    ?></th>
							<td>
							  <input type="checkbox" name="google_safe_browsing" id="google_safe_browsing" value="true" <?php 
    if ( get_option( 'teo_google_safe_browsing' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
								<?php 
    \esc_html_e( '(recommended to turn on)', 'events-optimizer' );
    ?>
							</td>
							</tr>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Verify URLs on missing https/ http', 'events-optimizer' );
    ?></th>
							<td>
							  <input type="checkbox" name="validate_url_https" id="validate_url_https" value="true" <?php 
    if ( get_option( 'teo_validate_url_https' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
								<?php 
    \esc_html_e( '(recommended to turn on)', 'events-optimizer' );
    ?>
							</td>
							</tr>	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Verify if URLs are redirected or permanently moved', 'events-optimizer' );
    ?></th>
							<td>
							  <input type="checkbox" name="validate_url_redirected_moved" id="validate_url_redirected_moved" value="true" <?php 
    if ( get_option( 'teo_validate_url_redirected_moved' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
								<?php 
    \esc_html_e( '(recommended to turn on)', 'events-optimizer' );
    ?>
							</td>
							</tr>														
						</table>

						<br><h3><?php 
    \esc_html_e( 'Google Places', 'events-optimizer' );
    ?></h3>
						<div id="modern-tribe-info">
							<?php 
    \esc_html_e( 'To automatically optimize your data the Google Places API is used.', 'events-optimizer' );
    ?><br>
							<li><?php 
    \esc_html_e( 'To set up and configure your API key check out the ', 'events-optimizer' );
    ?><a href="https://developers.google.com/maps/documentation/places/web-service" target="_blank">
							<?php 
    \esc_html_e( 'Google Places API documentation.', 'events-optimizer' );
    ?></a></li>
							<li><?php 
    \esc_html_e( 'Activate the Google PLACES API for the relevant project in the ', 'events-optimizer' );
    ?><a href="https://console.cloud.google.com/" target="_blank">
							<?php 
    \esc_html_e( 'Google Cloud Console.', 'events-optimizer' );
    ?></a>
							<?php 
    \esc_html_e( 'The easiest way for this is to use your (possibly already existing) Google MAPS API key from the ', 'events-optimizer' );
    ?>
							<?php 
    // Path to Events Calendar settings changed from V5.9 to V6.0
    $plugin_arr = get_plugin_data( WP_PLUGIN_DIR . '/the-events-calendar/the-events-calendar.php', false, false );
    
    if ( $plugin_arr['Version'] < 6 ) {
        echo  '<a href="/wp-admin/edit.php?page=tribe-common&tab=addons&post_type=tribe_events" target="_blank">' ;
    } else {
        echo  '<a href="/wp-admin/edit.php?page=tec-events-settings&tab=addons&post_type=tribe_events" target="_blank">' ;
    }
    
    ?>
							<?php 
    \esc_html_e( 'Events Calendar settings.', 'events-optimizer' );
    ?></a></li>
							<li><?php 
    \esc_html_e( 'Before using it please review the', 'events-optimizer' );
    ?><a href="https://developers.google.com/maps/billing/gmp-billing" target="_blank">
							<?php 
    \esc_html_e( 'pricing of the Google Places API.', 'events-optimizer' );
    ?></a></li>					
						</div>	
															
						<table class="form-table">
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Google Places API key', 'events-optimizer' );
    ?></th>
							<td><input type="text" name="google_places_api_key" id="google_places_api_key" size="44" value="<?php 
    echo  esc_attr( get_option( 'teo_google_places_api_key' ) ) ;
    ?>"  <?php 
    echo  "disabled" ;
    ?> />
							</td>						
							</tr>
							<th scope="row"><?php 
    \esc_html_e( 'Language (ISO Code)', 'events-optimizer' );
    ?></th>
							<td><input type="text" name="google_places_language" id="google_places_language" size="5" value="<?php 
    echo  esc_attr( get_option( 'teo_google_places_language' ) ) ;
    ?>"  <?php 
    echo  "disabled" ;
    ?> />
								<?php 
    \esc_html_e( '(according to', 'events-optimizer' );
    ?> 
								<a href="https://developers.google.com/maps/faq#languagesupport" target="_blank">
								<?php 
    \esc_html_e( 'Google Places API)', 'events-optimizer' );
    ?>
								</a>
							</td>

							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Phone number format', 'events-optimizer' );
    ?></th>
							<td>
							<select name="phone_number_format" id="phone_number_format"  <?php 
    echo  "disabled" ;
    ?> >
								<option value="international_phone_number" <?php 
    echo  ( $phone_number_format === "international_phone_number" ? 'selected="selected"' : '' ) ;
    ?>><?php 
    \esc_html_e( 'International', 'events-optimizer' );
    ?></option>
								<option value="formatted_phone_number" <?php 
    echo  ( $phone_number_format === "formatted_phone_number" ? 'selected="selected"' : '' ) ;
    ?>><?php 
    \esc_html_e( 'Local', 'events-optimizer' );
    ?></option>
							</select>
							<?php 
    \esc_html_e( '(int. = +49..., local = (089) 1234...)', 'events-optimizer' );
    ?>
							</td>
							</tr>

							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Address format', 'events-optimizer' );
    ?></th>
							<td>
							<select name="address_format" id="address_format"  <?php 
    echo  "disabled" ;
    ?> >
								<option value="street_number" <?php 
    echo  ( $address_format === "street_number" ? 'selected="selected"' : '' ) ;
    ?>><?php 
    \esc_html_e( 'Street name + number', 'events-optimizer' );
    ?></option>
								<option value="number_street" <?php 
    echo  ( $address_format === "number_street" ? 'selected="selected"' : '' ) ;
    ?>><?php 
    \esc_html_e( 'Street number + name', 'events-optimizer' );
    ?></option>
							</select>
							<?php 
    \esc_html_e( '(Sesame street 42 vs. 42th Sesame street)', 'events-optimizer' );
    ?>
							</td>
							</tr>

							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Preselection', 'events-optimizer' );
    ?></th>
							<td>
							<select name="preselection" id="preselection"  <?php 
    echo  "disabled" ;
    ?> >
								<option value="auto_completion" <?php 
    echo  ( $preselection === "auto_completion" ? 'selected="selected"' : '' ) ;
    ?>><?php 
    \esc_html_e( 'Auto completion of missing data', 'events-optimizer' );
    ?></option>
								<option value="full_replacement" <?php 
    echo  ( $preselection === "full_replacement" ? 'selected="selected"' : '' ) ;
    ?>><?php 
    \esc_html_e( 'Full replacement via Google Places', 'events-optimizer' );
    ?></option>
							</select>
							</td>
							</tr>
						</table>


						<br><h3><?php 
    \esc_html_e( 'Google Events', 'events-optimizer' );
    ?><span class='beta_version'>BETA</span></h3>
						<div id="modern-tribe-info">
							<?php 
    \esc_html_e( 'To automatically add events with Google Events data the DataForSEO API is used.', 'events-optimizer' );
    ?>
							<li><?php 
    \esc_html_e( 'To set it up and configure it check out ', 'events-optimizer' );
    ?><a href="https://developers.google.com/maps/documentation/places/web-service" target="_blank">
							<a href="https://dataforseo.com/?aff=142846" target="_blank"><?php 
    \esc_html_e( 'dataforseo.com', 'events-optimizer' );
    ?></a> 
							<?php 
    \esc_html_e( '(Free trial with Affiliate link).', 'events-optimizer' );
    ?></li>
							<li><?php 
    \esc_html_e( 'You find your API login and password in your', 'events-optimizer' );
    ?> <a href="https://app.dataforseo.com/api-dashboard/?aff=142846" target="_blank">
							<?php 
    \esc_html_e( 'DataForSEO Dashboard.', 'events-optimizer' );
    ?></a>
							<?php 
    \esc_html_e( 'Before using it please review the', 'events-optimizer' );
    ?> <a href="https://dataforseo.com/pricing/serp/serp-api/?aff=142846" target="_blank">
							<?php 
    \esc_html_e( 'pricing of the DataForSEO.', 'events-optimizer' );
    ?></a></li>
							<li><?php 
    \esc_html_e( 'Try out the search at', 'events-optimizer' );
    ?> 
							<a href="https://www.google.com/search?q=jazz&ibp=htl;events&rciv=evn#fpstate=tldetail" target="_blank">
							<?php 
    \esc_html_e( 'Google Events.', 'events-optimizer' );
    ?></a></li>
							<li><?php 
    \esc_html_e( 'It is recommended to add new events in a regular rhythm, e.g. every month. This can avoid duplicates.', 'events-optimizer' );
    ?></li>
						</div>
															
						<table class="form-table">
							<tr valign="top">							
							<th scope="row"><?php 
    \esc_html_e( 'DataForSEO API login', 'events-optimizer' );
    ?></th>
							<td><input type="text" name="dataforseo_api_login" id="dataforseo_api_login" size="30"  value="<?php 
    echo  esc_attr( get_option( 'teo_dataforseo_api_login' ) ) ;
    ?>"  <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>	
							<tr valign="top">							
							<th scope="row"><?php 
    \esc_html_e( 'DataForSEO API password', 'events-optimizer' );
    ?></th>
							<td><input type="text" name="dataforseo_api_password" id="dataforseo_api_password" size="30"  value="<?php 
    echo  esc_attr( get_option( 'teo_dataforseo_api_password' ) ) ;
    ?>"  <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>							
							<tr valign="top">							
							<th scope="row"><?php 
    \esc_html_e( 'Date range', 'events-optimizer' );
    ?></th>
							<td>
							<select name="dataforseo_date_range" id="dataforseo_date_range" <?php 
    echo  "disabled" ;
    ?> >  
							<?php 
    $date_range_options = array(
        'all'        => __( 'All upcoming events', 'events-optimizer' ),
        'today'      => __( 'Today', 'events-optimizer' ),
        'tomorrow'   => __( 'Tomorrow', 'events-optimizer' ),
        'weekend'    => __( 'This weekend', 'events-optimizer' ),
        'week'       => __( 'This week', 'events-optimizer' ),
        'next_week'  => __( 'Next week', 'events-optimizer' ),
        'month'      => __( 'This month', 'events-optimizer' ),
        'next_month' => __( 'Next month', 'events-optimizer' ),
    );
    foreach ( $date_range_options as $dr_value => $dr_decription ) {
        
        if ( $dr_value === get_option( 'teo_dataforseo_date_range' ) ) {
            echo  '<option value="' . $dr_value . '" selected>' . $dr_decription . '</option>' ;
        } else {
            echo  '<option value="' . $dr_value . '">' . $dr_decription . '</option>' ;
        }
    
    }
    ?>
							</select>  
							</td>
							</tr>
							<tr valign="top">							
							<th scope="row"><?php 
    \esc_html_e( 'Language (ISO code)', 'events-optimizer' );
    ?></th>
							<td><input type="text" name="dataforseo_language_code" id="dataforseo_language_code" size="10"  value="<?php 
    echo  esc_attr( get_option( 'teo_dataforseo_language_code' ) ) ;
    ?>"  <?php 
    echo  "disabled" ;
    ?> />
							<?php 
    \esc_html_e( '(according to', 'events-optimizer' );
    ?> 
							<a href="https://cdn.dataforseo.com/v3/languages/languages_serp_google_2022_01_17.csv">
							<?php 
    \esc_html_e( 'this list from DataForSEO)', 'events-optimizer' );
    ?>
							</a>
							</td>
							</tr>							
							<tr valign="top">							
							<th scope="row"><?php 
    \esc_html_e( 'Location code', 'events-optimizer' );
    ?></th>
							<td><input type="text" name="dataforseo_location_code" id="dataforseo_location_code" size="10"  value="<?php 
    echo  esc_attr( get_option( 'teo_dataforseo_location_code' ) ) ;
    ?>"  <?php 
    echo  "disabled" ;
    ?> />
							<?php 
    \esc_html_e( '(according to', 'events-optimizer' );
    ?>
							<a href="https://cdn.dataforseo.com/v3/locations/locations_serp_google_2022_10_05.csv">
							<?php 
    \esc_html_e( 'this list from DataForSEO)', 'events-optimizer' );
    ?>
							</a>
							</td>
							</tr>
						</table>							
						<table class="form-table">
							<div id="modern-tribe-info">
								<?php 
    \esc_html_e( 'The following events are already added from Google Events. They will be ignored when searching for additional events.', 'events-optimizer' );
    ?><br>
							</div>			
							<tr valign="top">
							<th scope="row">
								<input type="button" name="action" class="button" id="reset_objects_added_button" <?php 
    echo  'disabled' ;
    ?> value="<?php 
    _e( 'Reset list', 'events-optimizer' );
    ?>" />
							</th>
							<td>
								<?php 
    $ignored_and_added_objects = unserialize( get_option( 'teo_ignored_and_added_objects' ) );
    
    if ( empty($ignored_and_added_objects) === false ) {
        foreach ( $ignored_and_added_objects as $object ) {
            if ( $object['status'] === 'added' ) {
                echo  '<div id="object_' . $object['id'] . '">
												  		<a href="/wp-admin/post.php?post=' . $object['post_id'] . '&action=edit" target="_blank">' . get_the_title( $object['post_id'] ) . ' (' . date_format( date_create( $object['start_datetime_gp'] ), 'm.d.Y, H:i' ) . '</a>
														<img src="' . plugin_dir_url( __FILE__ ) . 'images/delete-x-red.svg" class="delete-icon" alt="remove object from list" onclick="remove_object(' . $object['id'] . ');" />&nbsp;&nbsp;&nbsp;
													</div>' ;
            }
        }
    } else {
        echo  '--' ;
    }
    
    ?>
							</td>							
							</tr>						
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Show added events', 'events-optimizer' );
    ?></th>
							<td>
							  <input type="checkbox" name="show_events_added" id="show_events_added" value="true" <?php 
    if ( get_option( 'teo_show_events_added' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>																																																						
						</table>
					
						<br><h3><?php 
    \esc_html_e( 'Fetch data from Google Places within single organizer form', 'events-optimizer' );
    ?></h3>				
						<div id="modern-tribe-info">
							<strong><?php 
    \esc_html_e( 'Only for advanced users who are familiar with Custom Fields (no support provided for this feature!)', 'events-optimizer' );
    ?></strong><br><br>
							<?php 
    \esc_html_e( 'In the single organizer form data from Google Places can be fetched.', 'events-optimizer' );
    ?><br>
							<li><?php 
    \esc_html_e( 'If you add custom fields with the following ids to the single organizer form they will be populated with the corresponding data from Google Places:', 'events-optimizer' );
    ?><br>		
							<?php 
    \esc_html_e( 'OrganizerAddress, OrganizerCity, OrganizerZip, OrganizerProvince, OrganizerState, OrganizerCountry', 'events-optimizer' );
    ?></li>												
							<li><?php 
    \esc_html_e( 'The full address can be populated in any input or textarea field. Enter the field id below.', 'events-optimizer' );
    ?></li>				
						</div>

						<table class="form-table">	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Field id for full address', 'events-optimizer' );
    ?></th>
							<td><input type="text" name="element_id" id="element_id" size="30" value="<?php 
    echo  esc_attr( get_option( 'teo_element_id' ) ) ;
    ?>"  <?php 
    echo  "disabled" ;
    ?> />
								<?php 
    \esc_html_e( '(e.g. "content" or "excerpt")', 'events-optimizer' );
    ?>
							</td>
							</tr>
						</table>

						<br><h3><?php 
    \esc_html_e( 'Ignored objects', 'events-optimizer' );
    ?></h3>				
						<div id="modern-tribe-info">
							<?php 
    \esc_html_e( 'The following objects are ignored when searching for issues.', 'events-optimizer' );
    ?><br>
						</div>
						<table class="form-table">	
							<tr valign="top">
							<th scope="row">
								<input type="button" name="action" class="button" id="reset_objects_ignored_button" <?php 
    echo  'disabled' ;
    ?> value="<?php 
    _e( 'Reset list', 'events-optimizer' );
    ?>" />
							</th>
							<td>
								<?php 
    $ignored_and_added_objects = unserialize( get_option( 'teo_ignored_and_added_objects' ) );
    
    if ( empty($ignored_and_added_objects) === false ) {
        echo  '<p><strong>' . __( 'Venues', 'events-optimizer' ) . '</strong></p>' ;
        foreach ( $ignored_and_added_objects as $object ) {
            if ( $object['status'] === 'ignored' and $object['type'] === 'tribe_venue' ) {
                echo  '<div id="object_' . $object['id'] . '">
												  		<a href="/wp-admin/post.php?post=' . $object['post_id'] . '&action=edit" target="_blank">' . get_the_title( $object['post_id'] ) . '</a>
														<img src="' . plugin_dir_url( __FILE__ ) . 'images/delete-x-red.svg" class="delete-icon" alt="remove object from list" onclick="remove_object(' . $object['id'] . ');" />&nbsp;&nbsp;&nbsp;
													</div>' ;
            }
        }
        echo  '<br><p><strong>' . __( 'Organizers', 'events-optimizer' ) . '</strong></p>' ;
        foreach ( $ignored_and_added_objects as $object ) {
            if ( $object['status'] === 'ignored' and $object['type'] === 'tribe_organizer' ) {
                echo  '<div id="object_' . $object['id'] . '">
												  		<a href="/wp-admin/post.php?post=' . $object['post_id'] . '&action=edit" target="_blank">' . get_the_title( $object['post_id'] ) . '</a>
														<img src="' . plugin_dir_url( __FILE__ ) . 'images/delete-x-red.svg" class="delete-icon" alt="remove object from list" onclick="remove_object(' . $object['id'] . ');" />&nbsp;&nbsp;&nbsp;
													</div>' ;
            }
        }
        echo  '<br><p><strong>' . __( 'Events', 'events-optimizer' ) . '</strong></p>' ;
        foreach ( $ignored_and_added_objects as $object ) {
            if ( $object['status'] === 'ignored' and $object['type'] === 'tribe_events' ) {
                
                if ( $object['post_id'] != '' ) {
                    echo  '<div id="object_' . $object['id'] . '">
															<a href="/wp-admin/post.php?post=' . $object['post_id'] . '&action=edit" target="_blank">' . get_the_title( $object['post_id'] ) . '</a>
															<img src="' . plugin_dir_url( __FILE__ ) . 'images/delete-x-red.svg" class="delete-icon" alt="remove object from list" onclick="remove_object(' . $object['id'] . ');" />&nbsp;&nbsp;&nbsp;
														  </div>' ;
                } else {
                    echo  '<div id="object_' . $object['id'] . '">' . $object['title_gp'] . ' (' . date_format( date_create( $object['start_datetime_gp'] ), get_option( 'date_format' ) . ", H:i" ) . ')' . ' <img src="' . plugin_dir_url( __FILE__ ) . 'images/delete-x-red.svg" class="delete-icon" alt="remove object from list" onclick="remove_object(' . $object['id'] . ');" />&nbsp;&nbsp;&nbsp;
													</div>' ;
                }
            
            }
        }
    } else {
        echo  '--' ;
    }
    
    ?>
							</td>
							</tr>							
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Show ignored objects', 'events-optimizer' );
    ?></th>
							<td>
							  <input type="checkbox" name="show_ignored_objects" id="show_ignored_objects" value="true" <?php 
    if ( get_option( 'teo_show_ignored_objects' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>
						</table>

						<br><h3><?php 
    \esc_html_e( 'Ignored fields', 'events-optimizer' );
    ?></h3>				
						<div id="modern-tribe-info">
							<?php 
    \esc_html_e( 'All fields checked will be ignored when searching for invalid data.', 'events-optimizer' );
    ?><br>				
						</div>
						<br><h3><?php 
    \esc_html_e( 'Venues', 'events-optimizer' );
    ?></h3>
						<table class="form-table">	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Description', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_venue_description" id="ignored_field_venue_description" value="true" <?php 
    if ( get_option( 'teo_ignored_field_venue_description' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>							
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Address', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_venue_address" id="ignored_field_venue_address" value="true" <?php 
    if ( get_option( 'teo_ignored_field_venue_address' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'ZIP', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_venue_zip" id="ignored_field_venue_zip" value="true" <?php 
    if ( get_option( 'teo_ignored_field_venue_zip' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'City', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_venue_city" id="ignored_field_venue_city" value="true" <?php 
    if ( get_option( 'teo_ignored_field_venue_city' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Province', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_venue_province" id="ignored_field_venue_province" value="true" <?php 
    if ( get_option( 'teo_ignored_field_venue_province' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'State', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_venue_state" id="ignored_field_venue_state" value="true" <?php 
    if ( get_option( 'teo_ignored_field_venue_state' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Country', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_venue_country" id="ignored_field_venue_country" value="true" <?php 
    if ( get_option( 'teo_ignored_field_venue_country' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Phone', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_venue_phone" id="ignored_field_venue_phone" value="true" <?php 
    if ( get_option( 'teo_ignored_field_venue_phone' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Website', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_venue_website" id="ignored_field_venue_website" value="true" <?php 
    if ( get_option( 'teo_ignored_field_venue_website' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Business Status', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_venue_business_status" id="ignored_field_venue_business_status" value="true" <?php 
    if ( get_option( 'teo_ignored_field_venue_business_status' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>																											
						</table>

						<br><h3><?php 
    \esc_html_e( 'Organizers', 'events-optimizer' );
    ?></h3>
						<table class="form-table">	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Description', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_organizer_description" id="ignored_field_organizer_description" value="true" <?php 
    if ( get_option( 'teo_ignored_field_organizer_description' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>								
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Phone', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_organizer_phone" id="ignored_field_organizer_phone" value="true" <?php 
    if ( get_option( 'teo_ignored_field_organizer_phone' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Website', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_organizer_website" id="ignored_field_organizer_website" value="true" <?php 
    if ( get_option( 'teo_ignored_field_organizer_website' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>																				
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Mail', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_organizer_mail" id="ignored_field_organizer_mail" value="true" <?php 
    if ( get_option( 'teo_ignored_field_organizer_mail' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Business Status', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_organizer_business_status" id="ignored_field_organizer_business_status" value="true" <?php 
    if ( get_option( 'teo_ignored_field_organizer_business_status' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>	
						</table>
						
						<br><h3><?php 
    \esc_html_e( 'Events', 'events-optimizer' );
    ?></h3>
						<table class="form-table">	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Description', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_event_description" id="ignored_field_event_description" value="true" <?php 
    if ( get_option( 'teo_ignored_field_event_description' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>		
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Start', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_event_start" id="ignored_field_event_start" value="true" <?php 
    if ( get_option( 'teo_ignored_field_event_start' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'End', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_event_end" id="ignored_field_event_end" value="true" <?php 
    if ( get_option( 'teo_ignored_field_event_end' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>								
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Venue', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_event_venue" id="ignored_field_event_venue" value="true" <?php 
    if ( get_option( 'teo_ignored_field_event_venue' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>																			
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Organizer', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_event_organizer" id="ignored_field_event_organizer" value="true" <?php 
    if ( get_option( 'teo_ignored_field_event_organizer' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Website', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_event_website" id="ignored_field_event_website" value="true" <?php 
    if ( get_option( 'teo_ignored_field_event_website' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>	
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Currency symbol', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_event_currency_symbol" id="ignored_field_event_currency_symbol" value="true" <?php 
    if ( get_option( 'teo_ignored_field_event_currency_symbol' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>
							<tr valign="top">
							<th scope="row"><?php 
    \esc_html_e( 'Cost', 'events-optimizer' );
    ?></th>
							<td><input type="checkbox" name="ignored_field_event_cost" id="ignored_field_event_cost" value="true" <?php 
    if ( get_option( 'teo_ignored_field_event_cost' ) === 'true' ) {
        echo  "checked" ;
    }
    ?> <?php 
    echo  "disabled" ;
    ?> />
							</td>
							</tr>
						</table>
						<br>
						<input type='submit' name='action' class='button-primary' id='save_settings' value='<?php 
    _e( 'Save changes', 'events-optimizer' );
    ?>' />
					</div>
				</form>
				<p>
					<div id='show_tab_settings'></div>
					<div id='loading_tab_settings'><?php 
    \esc_attr_e( 'SAVING', 'events-optimizer' );
    ?></div>
				</p>
			</div>
		</div>

		<!-- jQuery: Fade in/out buttons and call php functions to analyse data -->	
		<script type='text/javascript'>
		
			// Wait until the whole document has fully loaded and then do everything inside here ...
			jQuery(document).ready(function(){
				jQuery('#venues_with_invalid_data').click(function() { // Execute function when button is clicked
					jQuery("#venues_with_invalid_data").attr("disabled", true); // Disable button while analyzing
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'venues_wid', // call function "Venues with invalid data"
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
							jQuery("#loading_tab_venues").fadeIn('fast'); // Fade in loading icon and "analyzing" text
							jQuery("#show_results_venues").fadeOut("fast"); // Hide results otherwise they are show on the other tabs!
						},
						success: function(html){ // Function is called and if data is retrieved, store it in variable "html"
							jQuery("#loading_tab_venues").fadeOut('slow'); // Fade out loading icon and "analyzing" text
							jQuery("#show_results_venues").html( html ); // Show the html inside "show_results_venues" div
							jQuery("#show_results_venues").fadeIn("fast"); // Fade in the results
							jQuery("#venues_with_invalid_data").attr("disabled", false); // Enable button after analyzing
						}
					}); //close jQuery.ajax
					return false;
				});	

				jQuery('#duplicate_venues').click(function() {
					jQuery("#duplicate_venues").attr("disabled", true);		
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'duplicate_ven', // call function "Duplicate Venues"
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
							jQuery("#loading_tab_venues").fadeIn('fast');
							jQuery("#show_results_venues").fadeOut("fast");
						},
						success: function(html){
							jQuery("#loading_tab_venues").fadeOut('slow');
							jQuery("#show_results_venues").html( html );
							jQuery("#show_results_venues").fadeIn("fast");
							jQuery("#duplicate_venues").attr("disabled", false);
						}
					});
					return false;					
				});
				
				jQuery('#venues_google_places_optimization').click(function() {
					jQuery("#venues_google_places_optimization").attr("disabled", true);			
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'venues_optimization_wgp', // call function "Venues optimization with Google Places"
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
							jQuery("#loading_tab_venues").fadeIn('fast');
							jQuery("#show_results_venues").fadeOut("fast");
						},
						success: function(html){
							jQuery("#loading_tab_venues").fadeOut('slow');
							jQuery("#show_results_venues").html( html );
							jQuery("#show_results_venues").fadeIn("fast");
							jQuery("#venues_google_places_optimization").attr("disabled", false);						
						}
					});
					return false;					
				});

				jQuery('#organizers_with_invalid_data').click(function() {
					jQuery("#organizers_with_invalid_data").attr("disabled", true);
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'organizers_wid', // call function "Organizers with invalid data"
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
							jQuery("#loading_tab_organizers").fadeIn('fast');
							jQuery("#show_results_organizers").fadeOut("fast");
						},
						success: function(html){
							jQuery("#loading_tab_organizers").fadeOut('slow');
							jQuery("#show_results_organizers").html( html );
							jQuery("#show_results_organizers").fadeIn("fast");
							jQuery("#organizers_with_invalid_data").attr("disabled", false);
						}
					});
					return false;
				});	
	
				jQuery('#duplicate_organizers').click(function() {
					jQuery("#duplicate_organizers").attr("disabled", true);		
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'duplicate_org',  // call function "Duplicate Organizers"
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
							jQuery("#loading_tab_organizers").fadeIn('fast');
							jQuery("#show_results_organizers").fadeOut("fast");
						},
						success: function(html){
							jQuery("#loading_tab_organizers").fadeOut('slow');
							jQuery("#show_results_organizers").html( html );
							jQuery("#show_results_organizers").fadeIn("fast");
							jQuery("#duplicate_organizers").attr("disabled", false);
						}
					});
					return false;					
				});	

				
				jQuery('#organizers_google_places_optimization').click(function() {
					jQuery("#organizers_google_places_optimization").attr("disabled", true);
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'organizers_optimization_wgp', // call function "Organizers optimization with Google Places"
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
							jQuery("#loading_tab_organizers").fadeIn('fast');
							jQuery("#show_results_organizers").fadeOut("fast");
						},
						success: function(html){
							jQuery("#loading_tab_organizers").fadeOut('slow');
							jQuery("#show_results_organizers").html( html );
							jQuery("#show_results_organizers").fadeIn("fast");
							jQuery("#organizers_google_places_optimization").attr("disabled", false);
						}
					});
					return false;					
				})		

				jQuery('#events_with_invalid_data').click(function() {
					jQuery("#events_with_invalid_data").attr("disabled", true);		
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'events_wid', // call function "Events with invalid data"
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
							jQuery("#loading_tab_events").fadeIn('fast');
							jQuery("#show_results_events").fadeOut("fast");
						},
						success: function(html){
							jQuery("#loading_tab_events").fadeOut('slow');
							jQuery("#show_results_events").html( html );
							jQuery("#show_results_events").fadeIn("fast");
							jQuery("#events_with_invalid_data").attr("disabled", false);
						}
					});
					return false;					
				});	

				jQuery('#search_events_with_google_data').click(function() {
					jQuery("#search_events_with_google_data").attr("disabled", true);		
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'search_events_wgd', // call function "Search events with Google data"
							dataforseo_keyword:	escape( jQuery( '#dataforseo_keyword' ).val() ),
							dataforseo_depth:	escape( jQuery( '#dataforseo_depth' ).val() ),							
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
							//jQuery("#loading_tab_events").text('ANALYZING');							
							jQuery("#loading_tab_events").fadeIn('fast');
							jQuery("#show_results_events").fadeOut("fast");
						},
						success: function(html){
							jQuery("#loading_tab_events").fadeOut('slow');
							jQuery("#show_results_events").html( html );
							jQuery("#show_results_events").fadeIn("fast");
							jQuery("#search_events_with_google_data").attr("disabled", false);
						}
					});
					return false;					
				});	
								
				jQuery('#add_events_with_google_data').click(function() {
					jQuery("#add_events_with_google_data").attr("disabled", true);		
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'add_events_wgd', // call function "Add events from Google data"
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
							//jQuery("#loading_tab_events").text('DOWNLOAD SEARCH RESULTS');						
							jQuery("#loading_tab_events").fadeIn('fast');
							jQuery("#show_results_events").fadeOut("fast");
						},
						success: function(html){
							jQuery("#loading_tab_events").fadeOut('slow');
							jQuery("#show_results_events").html( html );
							jQuery("#show_results_events").fadeIn("fast");
							jQuery("#add_events_with_google_data").attr("disabled", false);
						}
					});
					return false;					
				});	

				jQuery('#save_settings').click(function() { //start function when button is clicked
					jQuery("#save_settings").attr("disabled", true); // Disable button while saving
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'save_set', // call function "Save settings"
							max_results_per_page: 					escape( jQuery( '#max_results_per_page' ).val() ),

							duplicate_organizers_levenshtein: 		escape( jQuery( '#duplicate_organizers_levenshtein' ).val() ),
							duplicate_venues_levenshtein: 			escape( jQuery( '#duplicate_venues_levenshtein' ).val() ),

							google_places_api_key: 					escape( jQuery( '#google_places_api_key' ).val() ),
							google_places_language: 				escape( jQuery( '#google_places_language' ).val() ),
							dataforseo_keyword:						escape( jQuery( '#dataforseo_keyword' ).val() ),
							dataforseo_api_login:					escape( jQuery( '#dataforseo_api_login' ).val() ),
							dataforseo_api_password:				escape( jQuery( '#dataforseo_api_password' ).val() ),
							dataforseo_location_code:				escape( jQuery( '#dataforseo_location_code' ).val() ),
							dataforseo_language_code:				escape( jQuery( '#dataforseo_language_code' ).val() ),							
							dataforseo_date_range:					escape( jQuery( '#dataforseo_date_range' ).val() ),							
																																				
							google_safe_browsing: 					document.getElementsByName( 'google_safe_browsing' )[0].checked,
							validate_url_https: 					document.getElementsByName( 'validate_url_https' )[0].checked,	
							validate_url_redirected_moved: 			document.getElementsByName( 'validate_url_redirected_moved' )[0].checked,							

							phone_number_format: 					escape( jQuery( '#phone_number_format' ).val() ),
							address_format: 						escape( jQuery( '#address_format' ).val() ),						
							preselection: 							escape( jQuery( '#preselection' ).val() ),

							element_id: 							escape( jQuery( '#element_id' ).val() ),
							show_ignored_objects: 					document.getElementsByName( 'show_ignored_objects' )[0].checked,	
							show_events_added: 						document.getElementsByName( 'show_events_added' )[0].checked,
							
							ignored_field_venue_description: 		document.getElementsByName( 'ignored_field_venue_description' )[0].checked,			
							ignored_field_venue_address: 			document.getElementsByName( 'ignored_field_venue_address' )[0].checked,								
							ignored_field_venue_zip: 				document.getElementsByName( 'ignored_field_venue_zip' )[0].checked,								
							ignored_field_venue_city: 				document.getElementsByName( 'ignored_field_venue_city' )[0].checked,								
							ignored_field_venue_province: 			document.getElementsByName( 'ignored_field_venue_province' )[0].checked,								
							ignored_field_venue_state: 				document.getElementsByName( 'ignored_field_venue_state' )[0].checked,								
							ignored_field_venue_country: 			document.getElementsByName( 'ignored_field_venue_country' )[0].checked,								
							ignored_field_venue_phone: 				document.getElementsByName( 'ignored_field_venue_phone' )[0].checked,								
							ignored_field_venue_website: 			document.getElementsByName( 'ignored_field_venue_website' )[0].checked,	
							ignored_field_venue_business_status: 	document.getElementsByName( 'ignored_field_venue_business_status' )[0].checked,
																					
							ignored_field_organizer_description: 	document.getElementsByName( 'ignored_field_organizer_description' )[0].checked,								
							ignored_field_organizer_phone: 			document.getElementsByName( 'ignored_field_organizer_phone' )[0].checked,								
							ignored_field_organizer_website: 		document.getElementsByName( 'ignored_field_organizer_website' )[0].checked,								
							ignored_field_organizer_mail: 			document.getElementsByName( 'ignored_field_organizer_mail' )[0].checked,
							ignored_field_organizer_business_status:document.getElementsByName( 'ignored_field_organizer_business_status' )[0].checked,
																						
							ignored_field_event_description: 		document.getElementsByName( 'ignored_field_event_description' )[0].checked,								
							ignored_field_event_start: 				document.getElementsByName( 'ignored_field_event_start' )[0].checked,								
							ignored_field_event_end: 				document.getElementsByName( 'ignored_field_event_end' )[0].checked,								
							ignored_field_event_venue: 				document.getElementsByName( 'ignored_field_event_venue' )[0].checked,								
							ignored_field_event_organizer: 			document.getElementsByName( 'ignored_field_event_organizer' )[0].checked,
							ignored_field_event_website: 			document.getElementsByName( 'ignored_field_event_website' )[0].checked,								
							ignored_field_event_currency_symbol: 	document.getElementsByName( 'ignored_field_event_currency_symbol' )[0].checked,		
							ignored_field_event_cost: 				document.getElementsByName( 'ignored_field_event_cost' )[0].checked,								
					
							//remove_settings: 					escape( jQuery( '#remove_settings' ).val() ),																							
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>'																		
						},
						beforeSend: function() {
							jQuery("#loading_tab_settings").fadeIn('fast');
							jQuery("#show_tab_settings").fadeOut("slow");
						}, 
						success: function(html){ //if data is retrieved, store it in html
							jQuery("#loading_tab_settings").fadeOut('slow');
							jQuery("#show_tab_settings").html( html ); //show the html inside formstatus div
							jQuery("#show_tab_settings").fadeIn("fast"); //animation
							jQuery("#save_settings").attr("disabled", false);
							location.reload(); // reload setting page that everything is shown with updated data
						}
					}); //close jQuery.ajax
					return false;					
				});

				jQuery('#reset_objects_added_button').click(function() {
					jQuery("#reset_objects_added_button").attr("disabled", true);	
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'reset_object_li', // call function "reset objects list"
							status: 'added',
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
						},
						success: function(html){
							jQuery("#reset_objects_added_button").attr("disabled", false);
							location.reload(); // reload setting page that everything is shown with updated data						
						}
					});
					return false;					
				});	

				jQuery('#reset_objects_ignored_button').click(function() {
					jQuery("#reset_objects_ignored_button").attr("disabled", true);	
					jQuery.ajax({
						type: "post",
						url: "admin-ajax.php",
						data: { 
							action: 'reset_object_li', // call function "reset objects list"
							status: 'ignored',
							_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
						},
						beforeSend: function() {
						},
						success: function(html){
							jQuery("#reset_objects_ignored_button").attr("disabled", false);
							location.reload(); // reload setting page that everything is shown with updated data						
						}
					});
					return false;					
				});	
																			
			});
			
			function remove_object(id) {

				jQuery("#object_"+id).attr('disabled','disabled').css('opacity',0.4);
				jQuery.ajax({
					type: "post",
					url: "admin-ajax.php",
					data: { 
						action: 'remove_obj',
						_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' ,
						id: id,
					},
					beforeSend: function() {
						jQuery("#object_"+id).fadeOut('fast');	// Fade out status after data is ignored	
					},
					success: function(html) {					
					}
				}); //close jQuery.ajax
				return false;	
			}			

		</script>
		
	<?php 
}

//----------------------------------------------------------------------------------------
// Ajax - helloworld
// https://odd.blog/2008/11/01/make-your-wordpress-plugin-talk-ajax/
//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------
// Venues with invalid data
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_venues_wid', 'venues_with_invalid_data' );
function venues_with_invalid_data()
{
    check_ajax_referer( 'events-optimizer-nonce' );
    // Maximum number of results to display per page
    $max_results_per_page = get_option( 'teo_max_results_per_page', 5 );
    // Objects to be ignored while searching for invalid data
    $ignored_and_added_objects = unserialize( get_option( 'teo_ignored_and_added_objects' ) );
    // Whether ignored objects should be shown or not
    $show_ignored_objects = get_option( 'teo_show_ignored_objects' );
    // Whether added objects should be shown or not
    $show_added_objects = get_option( 'teo_show_added_objects' );
    // Fields to be ignored while searching for invalid data
    $ignored_field_venue_description = get_option( 'teo_ignored_field_venue_description' );
    $ignored_field_venue_address = get_option( 'teo_ignored_field_venue_address' );
    $ignored_field_venue_zip = get_option( 'teo_ignored_field_venue_zip' );
    $ignored_field_venue_city = get_option( 'teo_ignored_field_venue_city' );
    $ignored_field_venue_province = get_option( 'teo_ignored_field_venue_province' );
    $ignored_field_venue_state = get_option( 'teo_ignored_field_venue_state' );
    $ignored_field_venue_country = get_option( 'teo_ignored_field_venue_country' );
    $ignored_field_venue_phone = get_option( 'teo_ignored_field_venue_phone' );
    $ignored_field_venue_website = get_option( 'teo_ignored_field_venue_website' );
    // Custom countries from Events Calendar Options
    $options = get_option( 'tribe_events_calendar_options', '' );
    
    if ( !empty($options['tribe_events_calendar_options']) ) {
        $countries = explode( PHP_EOL, $options['tribeEventsCountries'] );
    } else {
        $countries = array();
    }
    
    foreach ( $countries as $j => $country ) {
        if ( !empty(trim( substr( $country, strpos( $country, ' ' ) + 1 ) )) ) {
            $countries_arr[$j] = trim( substr( $country, strpos( $country, ' ' ) + 1 ) );
        }
    }
    $fields_arr = array(
        'ID'             => __( 'ID', 'events-optimizer' ),
        'post_title'     => __( 'Name', 'events-optimizer' ),
        'post_content'   => __( 'Description', 'events-optimizer' ),
        '_VenueAddress'  => __( 'Address', 'events-optimizer' ),
        '_VenueZip'      => __( 'ZIP', 'events-optimizer' ),
        '_VenueCity'     => __( 'City', 'events-optimizer' ),
        '_VenueProvince' => __( 'Province', 'events-optimizer' ),
        '_VenueState'    => __( 'State', 'events-optimizer' ),
        '_VenueCountry'  => __( 'Country', 'events-optimizer' ),
        '_VenuePhone'    => __( 'Phone', 'events-optimizer' ),
        '_VenueURL'      => __( 'Website', 'events-optimizer' ),
    );
    // Get the next index of the venue if function is called by "Show more" button
    
    if ( isset( $_POST['next_result'] ) ) {
        $next_result = urldecode( $_POST['next_result'] );
    } else {
        $next_result = 0;
    }
    
    $k = $next_result;
    // Set index to the next upcoming venue
    $venue = tribe_get_venues();
    $c = count( $venue );
    // Maximum amount of venues
    $i = 0;
    // Index to count for maximum results per page
    // Check if not all venues have been shown yet and maximum results has not been reached
    while ( $k < $c and $i < $max_results_per_page ) {
        // Hide venues that have no errors
        $found_error = false;
        $venue_details = get_post_meta( $venue[$k]->ID );
        $venue_details = $venue_details + array(
            'ID' => array( $venue[$k]->ID ),
        );
        $venue_details = $venue_details + array(
            'post_title' => array( $venue[$k]->post_title ),
        );
        $venue_details = $venue_details + array(
            'post_content' => array( $venue[$k]->post_content ),
        );
        // If venue isn't part of the ignored or added objects list show it
        
        if ( array_search( $venue[$k]->ID, array_column( $ignored_and_added_objects, 'post_id' ) ) === false or $show_ignored_objects === 'true' or $show_added_objects === 'true' ) {
            echo  '<form action="" method="POST" id="save_venue_wid_form_' . $k . '">' ;
            echo  '<br>' ;
            echo  '<table class="widefat fixed striped"><thead><tr><th>' ;
            \esc_html_e( 'Field', 'events-optimizer' );
            echo  '</th><th>' ;
            \esc_html_e( 'Value', 'events-optimizer' );
            echo  '</th><th>' ;
            \esc_html_e( 'Status', 'events-optimizer' );
            echo  '</th></tr></thead><tbody>' ;
            foreach ( $fields_arr as $field => $fieldname ) {
                $value = $venue_details[$field][0];
                switch ( $field ) {
                    case 'ID':
                        echo  '<tr><td>' . $fieldname . '</td><input type="hidden" name="' . $field . '" id="' . $field . '" value="' . $value . '"/><td><a href="/wp-admin/post.php?post=' . $venue[$k]->ID . '&action=edit" target="_blank">' . $value . ' <img src="' . plugin_dir_url( __FILE__ ) . 'images/external-link.png" class="external-link-icon" alt="External Link"/></a>' ;
                        echo  '<a href="https://www.google.com/search?q=' . urlencode( $venue[$k]->post_title . ' ' . $venue_details['_VenueCity'][0] ) . '" target="_blank">&nbsp;&nbsp;&nbsp;' ;
                        \esc_html_e( 'Search with Google for it', 'events-optimizer' );
                        echo  ' <img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a>' ;
                        echo  '</td><td>--</td></tr>' ;
                        break;
                    case 'post_content':
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><textarea name="' . $field . '" id="' . $field . '" rows="6" cols="30"></textarea></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $ignored_field_venue_description === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><textarea name="' . $field . '" id="' . $field . '" rows="6" cols="30">' . esc_textarea( $value ) . '</textarea></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                    case '_VenueZip':
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $ignored_field_venue_zip === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            
                            if ( strlen( $value ) < 4 ) {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-warning">' . __( 'Field content is very short', 'events-optimizer' ) . '</span></td></tr>' ;
                                if ( $ignored_field_venue_zip === 'false' ) {
                                    $found_error = true;
                                }
                            } else {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                            }
                        
                        }
                        
                        break;
                        // Only for Non-USA countries: set the province (= Bundesland)
                    // Only for Non-USA countries: set the province (= Bundesland)
                    case '_VenueProvince':
                        if ( $venue_details['_VenueCountry'][0] != __( 'United States', 'events-optimizer' ) ) {
                            
                            if ( empty($value) ) {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                                if ( $ignored_field_venue_province === 'false' ) {
                                    $found_error = true;
                                }
                            } else {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                            }
                        
                        }
                        break;
                        // Only for USA - set abbreviation of state, e.g. AZ for Arizona)
                    // Only for USA - set abbreviation of state, e.g. AZ for Arizona)
                    case '_VenueState':
                        if ( $venue_details['_VenueCountry'][0] === __( 'United States', 'events-optimizer' ) ) {
                            
                            if ( empty($value) ) {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                                if ( $ignored_field_venue_state === 'false' ) {
                                    $found_error = true;
                                }
                            } else {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                            }
                        
                        }
                        break;
                        // Check if country is in custom country list
                    // Check if country is in custom country list
                    case '_VenueCountry':
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $ignored_field_venue_country === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            // Custom countries available?
                            
                            if ( !empty($countries_arr) ) {
                                
                                if ( !in_array( $value, $countries_arr ) ) {
                                    echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Country not in custom country list', 'events-optimizer' ) . '</span></td></tr>' ;
                                    if ( $ignored_field_venue_country === 'false' ) {
                                        $found_error = true;
                                    }
                                } else {
                                    echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                                }
                            
                            } else {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                            }
                        
                        }
                        
                        break;
                    case '_VenuePhone':
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="https://www.google.de/search?q=phone+' . $venue_details['post_title'][0] . '" target="_blank"> <img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a></td><td><span class="field-status-error">' . $valid . '</td></tr>' ;
                            if ( $ignored_field_venue_phone === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="https://www.google.de/search?q=phone+' . $venue_details['post_title'][0] . '" target="_blank"> <img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                    case '_VenueURL':
                        $valid = url_valid( $value );
                        
                        if ( $valid != '' ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="https://www.google.de/search?q=' . $venue_details['post_title'][0] . '" target="_blank"> <img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a></td><td><span class="field-status-error">' . $valid . '</td></tr>' ;
                            if ( $ignored_field_venue_website === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="' . $value . '" target="_blank"><img src="' . plugin_dir_url( __FILE__ ) . 'images/external-link.png" class="external-link-icon" alt="External Link"/></a></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                    default:
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $field === 'post_title' ) {
                                $found_error = true;
                            }
                            if ( $field === '_VenueAddress' and $ignored_field_venue_address === 'false' ) {
                                $found_error = true;
                            }
                            if ( $field === '_VenueCity' and $ignored_field_venue_city === 'false' ) {
                                $found_error = true;
                            }
                            //if ( $field === '_VenuePhone' and $ignored_field_venue_phone === 'false' ) $found_error = true;
                        } else {
                            
                            if ( strlen( $value ) < 4 ) {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-warning">' . __( 'Field content is very short', 'events-optimizer' ) . '</span></td></tr>' ;
                                if ( $field === 'post_title' ) {
                                    $found_error = true;
                                }
                                if ( $field === '_VenueAddress' and $ignored_field_venue_address === 'false' ) {
                                    $found_error = true;
                                }
                                if ( $field === '_VenueCity' and $ignored_field_venue_city === 'false' ) {
                                    $found_error = true;
                                }
                                //if ( $field === '_VenuePhone' and $ignored_field_venue_phone === 'false' ) $found_error = true;
                            } else {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                            }
                        
                        }
                
                }
                // end switch
            }
            // end foreach
            echo  '</tbody>
				</table>
				<p><input type="button" name="action" class="button button-primary" id="save_venue_wid_button_' . $k . '" value="' . __( 'Save changes', 'events-optimizer' ) . '" onclick="save_form(' . "'" . $k . "'" . ');" />
				&nbsp;&nbsp;&nbsp;<input type="button" name="action" class="button delete" id="ignore_object_button_' . $k . '" value="' . __( 'Ignore', 'events-optimizer' ) . '" onclick="ignore_object(' . "'" . $k . "'" . ');"' ;
            echo  "disabled" ;
            echo  '/>
				</p><div id="status_save_venue_wid_' . $k . '">' . __( 'SAVING', 'events-optimizer' ) . '</div></p><br>
				</form>' ;
        }
        
        // end if array_search(
        $nonce = wp_create_nonce( 'events-optimizer-nonce' );
        ?>	
		
		<script  type='text/javascript'>
	
			function save_form(form_id){
				var datastring = jQuery("#save_venue_wid_form_"+form_id).serialize();
				jQuery("#save_venue_wid_button_"+form_id).attr("disabled", true); // Disable button while saving
				jQuery.ajax({
					type: "post",
					url: "admin-ajax.php",
					data: { 
						action: 'save_ven',
						_ajax_nonce: '<?php 
        echo  $nonce ;
        ?>' ,
						data: datastring,
					},
					beforeSend: function() {
						jQuery("#status_save_venue_wid_"+form_id).fadeIn('fast');  // Fade in status when button is clicked
					},
					success: function(html) {
						jQuery("#status_save_venue_wid_"+form_id).fadeOut('slow');	// Fade out status after data is saved
						jQuery("#save_venue_wid_button_"+form_id).attr("disabled", false); // Enable button after saving
						jQuery("#save_venue_wid_form_"+form_id).slideUp(); // Disable venue form after saving							
					}
				}); //close jQuery.ajax
				return false;	
			}
			function ignore_object(form_id){	
				var datastring = jQuery("#save_venue_wid_form_"+form_id).serialize() + '&type=tribe_venue&status=ignored';
				jQuery("#ignore_object_button_"+form_id).attr("disabled", true); // Disable button while ignoring
				jQuery.ajax({
					type: "post",
					url: "admin-ajax.php",
					data: { 
						action: 'add_obj',
						_ajax_nonce: '<?php 
        echo  $nonce ;
        ?>' ,
						data: datastring,
					},
					beforeSend: function() {
					},
					success: function(html) {
						jQuery("#status_save_venue_wid_"+form_id).fadeOut('slow');	// Fade out status after data is ignored
						jQuery("#ignore_object_button_"+form_id).attr("disabled", false); // Enable button after ignoring
						jQuery("#save_venue_wid_form_"+form_id).slideUp(); // Slide venue form away after ignoring							
					}
				}); //close jQuery.ajax
				return false;	
			}
		</script>	
		
		<style type='text/css'>
			#status_save_venue_wid_<?php 
        echo  $k ;
        ?> { 
				display: none;
				clear: both;
				background: url(images/loading.gif) left top no-repeat; 
				text-align: left;
				padding: 0px 0px 30px 25px; 
			}
			<?php 
        if ( $found_error === false ) {
            echo  "#save_venue_wid_form_" . $k . ", #save_venue_wid_button_" . $k . " { display: none; }" ;
        }
        ?>
		</style>

		<?php 
        // if invalid data is found increase counter for maximum results per page
        if ( $found_error === true ) {
            $i++;
        }
        $k++;
    }
    // end while
    
    if ( $k < $c ) {
        echo  '<div id="additional_results_venues_wid_' . $k . '"<p><strong>' . __( 'Additional results available.', 'events-optimizer' ) . '</strong></p></div>' ;
        echo  '<p><input type="submit" name="action" class="button button-primary" id="show_more_venues_wid_button_' . $k . '" value="' . __( 'Show more', 'events-optimizer' ) . '" onclick="show_more(' . "'" . $k . "'" . ');" /></p>' ;
        echo  '<div id="show_more_venues_wid"></div>' ;
        echo  '<div id="status_show_more_venues_wid_' . $k . '">' . __( 'ANALYZING', 'events-optimizer' ) . '</div>' ;
    }
    
    if ( $next_result + $max_results_per_page >= $c ) {
        echo  '<span class="field-status-ok">' . __( 'No (more) results found!', 'events-optimizer' ) . '</span>' ;
    }
    $nonce = wp_create_nonce( 'events-optimizer-nonce' );
    ?>	
		
	<script  type='text/javascript'>
	
		function show_more(form_id){
       		jQuery("#show_more_venues_wid_button_"+form_id).fadeOut('slow'); // Hide button after  		
    		jQuery("#show_more_venues_wid_button_"+form_id).attr("disabled", true); // Disable button while retrieving more results
    		jQuery.ajax({
				type: "post",
				url: "admin-ajax.php",
				data: { 
					action: 'venues_wid',
					next_result: form_id,
					_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
				},
				beforeSend: function() {
					jQuery("#status_show_more_venues_wid_"+form_id).fadeIn('fast');  // Fade in status when button is clicked
					jQuery("#additional_results_venues_wid_"+form_id).fadeOut('slow');	// Fade out text "Additional results ..." after data is saved
				},
				success: function(html) {
					jQuery("#show_more_venues_wid_button_"+form_id).attr("disabled", false); // Enable button after
					jQuery("#status_show_more_venues_wid_"+form_id).fadeOut('slow');	// Fade out status after data is saved
					jQuery("#show_more_venues_wid").append(html); // Add the additional results to page
				}
    		}); //close jQuery.ajax
    		return false;	
    	}	
	</script>

	<style type='text/css'>
		#status_show_more_venues_wid_<?php 
    echo  $k ;
    ?> { 
			display: none;
			clear: both;
			background: url(images/loading.gif) left top no-repeat; 
			text-align: left;
			padding: 0px 0px 30px 25px; 
		}
	</style>

	<?php 
    die;
}

//----------------------------------------------------------------------------------------
// Save venue data (for invalid data and Google Places optimization)
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_save_ven', 'save_venue' );
function save_venue()
{
    check_ajax_referer( 'events-optimizer-nonce' );
    parse_str( $_POST['data'], $venue );
    // Title and description can't be updated directly with the TEC API (empty fields gets ignored - bug?) and therefore it needs to be updated seperatly
    $venue_post_arr = array(
        'ID'           => sanitize_text_field( $venue['ID'] ),
        'post_title'   => sanitize_text_field( $venue['post_title'] ),
        'post_content' => sanitize_textarea_field( $venue['post_content'] ),
    );
    wp_update_post( $venue_post_arr );
    // Update venues with values
    $venue_arr = array(
        'Address'       => sanitize_text_field( $venue['_VenueAddress'] ),
        'GeoAddress'    => sanitize_text_field( $venue['_VenueAddress'] ) . ' ' . sanitize_text_field( $venue['_VenueZip'] ) . ' ' . sanitize_text_field( $venue['_VenueCity'] ) . ' ' . sanitize_text_field( $venue['_VenueZip'] ),
        'Zip'           => sanitize_text_field( $venue['_VenueZip'] ),
        'City'          => sanitize_text_field( $venue['_VenueCity'] ),
        'State'         => sanitize_text_field( $venue['_VenueState'] ),
        'Province'      => sanitize_text_field( $venue['_VenueProvince'] ),
        'StateProvince' => sanitize_text_field( $venue['_VenueProvince'] ),
        'Country'       => sanitize_text_field( $venue['_VenueCountry'] ),
        'Phone'         => sanitize_text_field( $venue['_VenuePhone'] ),
        'URL'           => sanitize_text_field( $venue['_VenueURL'] ),
    );
    tribe_update_venue( $venue['ID'], $venue_arr );
    die;
}

//----------------------------------------------------------------------------------------
// Duplicate Venues
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_duplicate_ven', 'get_duplicate_venues' );
function get_duplicate_venues()
{
}

//----------------------------------------------------------------------------------------
// Merge Venues
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_merge_ven', 'merge_venues' );
function merge_venues()
{
}

//----------------------------------------------------------------------------------------
// Venues: Optimization with Google Places
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_venues_optimization_wgp', 'venues_optimization_with_google_places' );
function venues_optimization_with_google_places()
{
}

//----------------------------------------------------------------------------------------
// Fetch data from Google Places for single venue
//----------------------------------------------------------------------------------------
add_action( 'tribe_events_venue_before_metabox', 'fetch_venue_data' );
function fetch_venue_data()
{
}

//----------------------------------------------------------------------------------------
// Get venue data from Google Places and hand it over to Java Script function above
// https://www.codexworld.com/post-get-json-data-from-php-script-jquery-ajax/
// https://www.mediaevent.de/javascript/json.html
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_fetch_venue_data_fgp', 'fetch_venue_data_from_google_places' );
function fetch_venue_data_from_google_places()
{
}

//----------------------------------------------------------------------------------------
// Organizers with invalid data
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_organizers_wid', 'organizers_with_invalid_data' );
function organizers_with_invalid_data()
{
    check_ajax_referer( 'events-optimizer-nonce' );
    // Maximum number of results to display per page
    $max_results_per_page = get_option( 'teo_max_results_per_page', 5 );
    // Objects to be ignored while searching for invalid data
    $ignored_and_added_objects = unserialize( get_option( 'teo_ignored_and_added_objects' ) );
    if ( empty($ignored_and_added_objects) ) {
        $ignored_objects = array();
    }
    // Whether ignored objects should be shown or not
    $show_ignored_objects = get_option( 'teo_show_ignored_objects' );
    // Whether added objects should be shown or not
    $show_added_objects = get_option( 'teo_show_added_objects' );
    // Fields to be ignored while searching for invalid data
    $ignored_field_organizer_description = get_option( 'teo_ignored_field_organizer_description' );
    $ignored_field_organizer_phone = get_option( 'teo_ignored_field_organizer_phone' );
    $ignored_field_organizer_website = get_option( 'teo_ignored_field_organizer_website' );
    $ignored_field_organizer_mail = get_option( 'teo_ignored_field_organizer_mail' );
    $fields_arr = array(
        'ID'                => __( 'ID', 'events-optimizer' ),
        'post_title'        => __( 'Name', 'events-optimizer' ),
        'post_content'      => __( 'Description', 'events-optimizer' ),
        '_OrganizerPhone'   => __( 'Phone', 'events-optimizer' ),
        '_OrganizerWebsite' => __( 'Website', 'events-optimizer' ),
        '_OrganizerEmail'   => __( 'Mail', 'events-optimizer' ),
    );
    // Get the next index of the organizer if function is called by "Show more" button
    
    if ( isset( $_POST['next_result'] ) ) {
        $next_result = urldecode( $_POST['next_result'] );
    } else {
        $next_result = 0;
    }
    
    $k = $next_result;
    // Set index to the next upcoming organizer
    $organizer = tribe_get_organizers();
    $c = count( $organizer );
    // Maximum amount of organizers
    $i = 0;
    // Index to count for maximum results per page
    // Check if not all organizers have been shown yet and maximum results has not been reached
    while ( $k < $c and $i < $max_results_per_page ) {
        // Hide organizers that have no errors
        $found_error = false;
        $organizer_details = get_post_meta( $organizer[$k]->ID );
        $organizer_details = $organizer_details + array(
            'ID' => array( $organizer[$k]->ID ),
        );
        $organizer_details = $organizer_details + array(
            'post_title' => array( $organizer[$k]->post_title ),
        );
        $organizer_details = $organizer_details + array(
            'post_content' => array( $organizer[$k]->post_content ),
        );
        // If organizer isn't part of the ignored or added objects list show it
        
        if ( array_search( $organizer[$k]->ID, array_column( $ignored_and_added_objects, 'post_id' ) ) === false or $show_ignored_objects === 'true' or $show_added_objects === 'true' ) {
            echo  '<form action="" method="POST" id="save_organizer_wid_form_' . $k . '">' ;
            echo  '<table class="widefat fixed striped"><thead><tr><th>' ;
            \esc_html_e( 'Field', 'events-optimizer' );
            echo  '</th><th>' ;
            \esc_html_e( 'Value', 'events-optimizer' );
            echo  '</th><th>' ;
            \esc_html_e( 'Status', 'events-optimizer' );
            echo  '</th></tr></thead><tbody>' ;
            foreach ( $fields_arr as $field => $fieldname ) {
                $value = $organizer_details[$field][0];
                echo  '<input type="hidden" name="index" id="index" value="' . $k . '"/>' ;
                switch ( $field ) {
                    case 'ID':
                        echo  '<tr><td>' . $fieldname . '</td><input type="hidden" name="' . $field . '" id="' . $field . '" value="' . $value . '"/><td><a href="/wp-admin/post.php?post=' . $organizer[$k]->ID . '&action=edit" target="_blank">' . $value . ' <img src="' . plugin_dir_url( __FILE__ ) . 'images/external-link.png" class="external-link-icon" alt="External Link"/></a>' ;
                        echo  '<a href="https://www.google.com/search?q=' . urlencode( $organizer[$k]->post_title ) . '" target="_blank">&nbsp;&nbsp;&nbsp;' ;
                        \esc_html_e( 'Search with Google for it', 'events-optimizer' );
                        echo  ' <img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a>' ;
                        echo  '</td><td>--</td></tr>' ;
                        break;
                    case 'post_content':
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><textarea name="' . $field . '" id="' . $field . '" rows="6" cols="30"></textarea></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $ignored_field_organizer_description === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><textarea name="' . $field . '" id="' . $field . '" rows="6" cols="30">' . esc_textarea( $value ) . '</textarea></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                    case '_OrganizerPhone':
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="https://www.google.de/search?q=phone+' . $organizer_details['post_title'][0] . '" target="_blank"><img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a></td><td><span class="field-status-error">' . $valid . '</td></tr>' ;
                            if ( $ignored_field_organizer_phone === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="https://www.google.de/search?q=phone+' . $organizer_details['post_title'][0] . '" target="_blank"><img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                    case '_OrganizerWebsite':
                        $valid = url_valid( $value );
                        
                        if ( $valid != '' ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="https://www.google.de/search?q=' . $organizer_details['post_title'][0] . '" target="_blank"> <img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a></td><td><span class="field-status-error">' . $valid . '</td></tr>' ;
                            if ( $ignored_field_organizer_website === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/><a href="' . $value . '" target="_blank"> <img src="' . plugin_dir_url( __FILE__ ) . 'images/external-link.png" class="external-link-icon" alt="External Link"/></a></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                        // Check if mail is valid
                    // Check if mail is valid
                    case '_OrganizerEmail':
                        $valid = mail_valid( $value );
                        
                        if ( $valid != '' ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="https://www.google.de/search?q=e-mail+' . $organizer_details['post_title'][0] . '" target="_blank"><img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a></td><td><span class="field-status-error">' . $valid . '</td></tr>' ;
                            if ( $ignored_field_organizer_mail === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="https://www.google.de/search?q=e-mail+' . $organizer_details['post_title'][0] . '" target="_blank"><img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                    default:
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $field === 'post_title' ) {
                                $found_error = true;
                            }
                            //if ( $field === '_OrganizerPhone' and $ignored_field_organizer_phone === 'false') $found_error = true;
                        } else {
                            
                            if ( strlen( $value ) <= 4 ) {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-warning">' . __( 'Field content is very short', 'events-optimizer' ) . '</span></td></tr>' ;
                                if ( $field === 'post_title' ) {
                                    $found_error = true;
                                }
                                //if ( $field === '_OrganizerPhone' and $ignored_field_organizer_phone === 'false') $found_error = true;
                            } else {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                            }
                        
                        }
                
                }
                // end switch
            }
            // end foreach
            echo  '</tbody>
				</table>	
				<p><input type="button" name="action" class="button button-primary" id="save_organizer_wid_button_' . $k . '" value="' . __( 'Save changes', 'events-optimizer' ) . '" onclick="save_form(' . "'" . $k . "'" . ');" />
				&nbsp;&nbsp;&nbsp;<input type="button" name="action" class="button delete" id="ignore_object_button_' . $k . '" value="' . __( 'Ignore', 'events-optimizer' ) . '" onclick="ignore_object(' . "'" . $k . "'" . ');"' ;
            echo  "disabled" ;
            echo  '/>
				</p><div id="status_save_organizer_wid' . $k . '">' . __( 'SAVING', 'events-optimizer' ) . '</div></p><br>
				</form>' ;
        }
        
        // end if array_search(
        $nonce = wp_create_nonce( 'events-optimizer-nonce' );
        ?>	

		<script  type='text/javascript'>
	
			function save_form(form_id){
				var datastring = jQuery("#save_organizer_wid_form_"+form_id).serialize(); 
				jQuery("#save_organizer_wid_button_"+form_id).attr("disabled", true); // Disable button while saving
				jQuery.ajax({
					type: "post",
					url: "admin-ajax.php",
					data: { 
						action: 'save_org',
						_ajax_nonce: '<?php 
        echo  $nonce ;
        ?>' ,
						data: datastring,
						},
					beforeSend: function() {
						jQuery("#status_save_organizer_wid_"+form_id).fadeIn('fast');  // Fade in status when button is clicked
						},
					success: function(html) {
						jQuery("#status_save_organizer_wid_"+form_id).fadeOut('slow');	// Fade out status after data is saved
						jQuery("#save_organizer_wid_button_"+form_id).attr("disabled", false); // Enable button after saving
						jQuery("#save_organizer_wid_form_"+form_id).slideUp(); // Slide organizer form away after saving				
					}
				}); //close jQuery.ajax
				return false;	
			}
			function ignore_object(form_id){
				var datastring = jQuery("#save_organizer_wid_form_"+form_id).serialize() + '&type=tribe_organizer&status=ignored';
				jQuery("#ignore_object_button_"+form_id).attr("disabled", true); // Disable button while ignoring
				jQuery.ajax({
					type: "post",
					url: "admin-ajax.php",
					data: { 
						action: 'add_obj',
						_ajax_nonce: '<?php 
        echo  $nonce ;
        ?>' ,
						data: datastring,
					},
					beforeSend: function() {
					},
					success: function(html) {
						jQuery("#status_save_organizer_wid_"+form_id).fadeOut('slow');	// Fade out status after data is ignored
						jQuery("#ignore_object_button_"+form_id).attr("disabled", false); // Enable button after ignoring
						jQuery("#save_organizer_wid_form_"+form_id).slideUp(); // Slide organizer form away after ignoring							
					}
				}); //close jQuery.ajax
				return false;	
			}
		</script>	
		
		<style type='text/css'>
			#status_save_organizer_wid<?php 
        echo  $k ;
        ?> { 
				display: none;
				clear: both;
				background: url(images/loading.gif) left top no-repeat; 
				text-align: left;
				padding: 0px 0px 30px 25px; 
			}
			<?php 
        if ( $found_error === false ) {
            echo  "#save_organizer_wid_form_" . $k . ", #save_organizer_wid_button_" . $k . " { display: none; }" ;
        }
        ?>
		</style>

		<?php 
        // if invalid data is found increase counter for maximum results per page
        if ( $found_error === true ) {
            $i++;
        }
        $k++;
    }
    // end while
    
    if ( $k < $c ) {
        echo  '<div id="additional_results_organizers_wid_' . $k . '"<p><strong>' . __( 'Additional results available.', 'events-optimizer' ) . '</strong></p></div>' ;
        echo  '<p><input type="submit" name="action" class="button button-primary" id="show_more_organizers_wid_button_' . $k . '" value="' . __( 'Show more', 'events-optimizer' ) . '" onclick="show_more(' . "'" . $k . "'" . ');" /></p>' ;
        echo  '<div id="show_more_organizers_wid"></div>' ;
        echo  '<div id="status_show_more_organizers_wid_' . $k . '">' . __( 'ANALYZING', 'events-optimizer' ) . '</div>' ;
    }
    
    if ( $next_result + $max_results_per_page >= $c ) {
        echo  '<span class="field-status-ok">' . __( 'No (more) results found!', 'events-optimizer' ) . '</span>' ;
    }
    $nonce = wp_create_nonce( 'events-optimizer-nonce' );
    ?>	
		
	<script  type='text/javascript'>
	
		function show_more(form_id){
			jQuery("#show_more_organizers_wid_button_"+form_id).fadeOut('slow'); // Hide button after  		
			jQuery("#show_more_organizers_wid_button_"+form_id).attr("disabled", true); // Disable button while retrieving more results
			jQuery.ajax({
				type: "post",
				url: "admin-ajax.php",
				data: { 
					action: 'organizers_wid',
					next_result: form_id,
					_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
				},
				beforeSend: function() {
					jQuery("#status_show_more_organizers_wid_"+form_id).fadeIn('fast');  // Fade in status when button is clicked
					jQuery("#additional_results_organizers_wid_"+form_id).fadeOut('slow');	// Fade out text "Additional results ..." after data is saved
				},
				success: function(html) {
					jQuery("#show_more_organizers_button_"+form_id).attr("disabled", false); // Enable button after
					jQuery("#status_show_more_organizers_wid_"+form_id).fadeOut('slow');	// Fade out status after data is saved
					jQuery("#show_more_organizers_wid").append(html); // Add the additional results to page
				}
			}); //close jQuery.ajax
			return false;	
		}	
	</script>

	<style type='text/css'>
		#status_show_more_organizers_wid_<?php 
    echo  $k ;
    ?> { 
			display: none;
			clear: both;
			background: url(images/loading.gif) left top no-repeat; 
			text-align: left;
			padding: 0px 0px 30px 25px; 
		}
	</style>

	<?php 
    die;
}

//----------------------------------------------------------------------------------------
// Save organizer data (for invalid data and Optimization with Google Places)
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_save_org', 'save_organizer' );
function save_organizer()
{
    check_ajax_referer( 'events-optimizer-nonce' );
    parse_str( $_POST['data'], $organizer );
    // Title and description are not part of the post_meta therefore they need to be updated seperatly
    $organizer_post_arr = array(
        'ID'           => sanitize_text_field( $organizer['ID'] ),
        'post_title'   => sanitize_text_field( $organizer['post_title'] ),
        'post_content' => sanitize_text_field( $organizer['post_content'] ),
    );
    wp_update_post( $organizer_post_arr );
    // Update organizer with values
    $organizer_arr = array(
        'Phone'   => sanitize_text_field( $organizer['_OrganizerPhone'] ),
        'Website' => sanitize_text_field( $organizer['_OrganizerWebsite'] ),
        'Email'   => sanitize_email( $organizer['_OrganizerEmail'] ),
    );
    tribe_update_organizer( $organizer['ID'], $organizer_arr );
    die;
}

//----------------------------------------------------------------------------------------
// Duplicate Organizers
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_duplicate_org', 'duplicate_organizers' );
function duplicate_organizers()
{
}

//----------------------------------------------------------------------------------------
// Merge Organizers
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_merge_org', 'merge_organizers' );
function merge_organizers()
{
}

//----------------------------------------------------------------------------------------
// Organizers: Optimization with Google Places
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_organizers_optimization_wgp', 'organizers_optimization_with_google_places' );
function organizers_optimization_with_google_places()
{
}

//----------------------------------------------------------------------------------------
// Fetch data from Google Places for single organizer
//----------------------------------------------------------------------------------------
add_action( 'tribe_events_organizer_before_metabox', 'fetch_organizer_data' );
function fetch_organizer_data()
{
}

//----------------------------------------------------------------------------------------
// Get organizer data from Google Places and hand it over to Java Script function above
// https://www.codexworld.com/post-get-json-data-from-php-script-jquery-ajax/
// https://www.mediaevent.de/javascript/json.html
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_fetch_organizer_data_fgp', 'fetch_organizer_data_from_google_places' );
function fetch_organizer_data_from_google_places()
{
}

//----------------------------------------------------------------------------------------
// Events with invalid data
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_events_wid', 'events_with_invalid_data' );
function events_with_invalid_data()
{
    check_ajax_referer( 'events-optimizer-nonce' );
    // Maximum number of results to display per page
    $max_results_per_page = get_option( 'teo_max_results_per_page', 5 );
    // Objects to be ignored while searching for invalid data
    $ignored_and_added_objects = unserialize( get_option( 'teo_ignored_and_added_objects' ) );
    if ( empty($ignored_and_added_objects) ) {
        $ignored_objects = array();
    }
    // Whether ignored objects should be shown or not
    $show_ignored_objects = get_option( 'teo_show_ignored_objects' );
    // Whether added objects should be shown or not
    $show_added_objects = get_option( 'teo_show_added_objects' );
    // Fields to be ignored while searching for invalid data
    $ignored_field_event_description = get_option( 'teo_ignored_field_event_description' );
    $ignored_field_event_start = get_option( 'teo_ignored_field_event_start' );
    $ignored_field_event_end = get_option( 'teo_ignored_field_event_end' );
    $ignored_field_event_venue = get_option( 'teo_ignored_field_event_venue' );
    $ignored_field_event_organizer = get_option( 'teo_ignored_field_event_organizer' );
    $ignored_field_event_website = get_option( 'teo_ignored_field_event_website' );
    $ignored_field_event_currency_symbol = get_option( 'teo_ignored_field_event_currency_symbol' );
    $ignored_field_event_cost = get_option( 'teo_ignored_field_event_cost' );
    // Get custom currency symbols from Events Calendar Options
    $options = get_option( 'tribe_events_calendar_options', '' );
    
    if ( !empty($options['tribe_ext_ce_cost_currency_symbols']) ) {
        $currency_symbols_arr = explode( '|', $options['tribe_ext_ce_cost_currency_symbols'] );
    } else {
        $currency_symbols_arr = array();
    }
    
    // If there are no custom currencies use the standard currency from the Events Calendar Options
    if ( empty(array_filter( $currency_symbols_arr )) ) {
        if ( !empty($options['defaultCurrencySymbol']) ) {
            $currency_symbols_arr[0] = $options['defaultCurrencySymbol'];
        }
    }
    // Get existing venues from Events Calendar and create sorted array for dropdown list
    $venues_unordered_arr = tribe_get_venues();
    foreach ( $venues_unordered_arr as $venue ) {
        $venues_arr[] = array(
            'ID'   => $venue->ID,
            'Name' => $venue->post_title,
        );
    }
    setlocale( LC_COLLATE, get_locale() );
    $name_arr = array_column( $venues_arr, 'Name' );
    array_multisort(
        $name_arr,
        SORT_ASC,
        SORT_LOCALE_STRING,
        $venues_arr
    );
    // Get existing organizers from Events Calendar and create sorted array for dropdown list
    $organizers_unordered_arr = tribe_get_organizers();
    foreach ( $organizers_unordered_arr as $organizer ) {
        $organizers_arr[] = array(
            'ID'   => $organizer->ID,
            'Name' => $organizer->post_title,
        );
    }
    unset( $name_arr );
    unset( $name_lowercase_arr );
    $name_arr = array_column( $organizers_arr, 'Name' );
    array_multisort(
        $name_arr,
        SORT_ASC,
        SORT_LOCALE_STRING,
        $organizers_arr
    );
    $fields_arr = array(
        'ID'                   => __( 'ID', 'events-optimizer' ),
        'post_title'           => __( 'Name', 'events-optimizer' ),
        'post_content'         => __( 'Description', 'events-optimizer' ),
        '_EventStartDate'      => __( 'Start', 'events-optimizer' ),
        '_EventEndDate'        => __( 'End', 'events-optimizer' ),
        '_EventVenueID'        => __( 'Venue', 'events-optimizer' ),
        '_EventOrganizerID'    => __( 'Organizer', 'events-optimizer' ),
        '_EventURL'            => __( 'Website', 'events-optimizer' ),
        '_EventCost'           => __( 'Cost', 'events-optimizer' ),
        '_EventCurrencySymbol' => __( 'Currency Symbol', 'events-optimizer' ),
    );
    // Get the next index of the venue if function is called by "Show more" button
    
    if ( isset( $_POST['next_result'] ) ) {
        $next_result = urldecode( $_POST['next_result'] );
    } else {
        $next_result = 0;
    }
    
    $k = $next_result;
    // Set index to the next upcoming venue
    $i = 0;
    // Counter for maximum results per page
    $events_offset = array_count_key( $ignored_and_added_objects, 'tribe_events' );
    $event = tribe_get_events( [
        'posts_per_page' => $next_result + $events_offset + 3 * $max_results_per_page,
    ] );
    $max_events = wp_count_posts( 'tribe_events' )->publish;
    // Check if not all venues have been shown yet and maximum results has not been reached
    while ( $k < $max_events and $i < $max_results_per_page ) {
        // Hide venues that have no errors
        $found_error = false;
        $event_details = get_post_meta( $event[$k]->ID );
        $event_details = $event_details + array(
            'ID' => array( $event[$k]->ID ),
        );
        $event_details = $event_details + array(
            'post_title' => array( $event[$k]->post_title ),
        );
        $event_details = $event_details + array(
            'post_content' => array( $event[$k]->post_content ),
        );
        $event_details = $event_details + array(
            '_EventVenueID' => array( $event[$k]->_EventVenueID ),
        );
        $event_details = $event_details + array(
            '_EventOrganizerID' => array( $event[$k]->_EventOrganizerID ),
        );
        // If event isn't part of the ignored or added objects list show it
        
        if ( array_search( $event[$k]->ID, array_column( $ignored_and_added_objects, 'post_id' ) ) === false or $show_ignored_objects === 'true' or $show_added_objects === 'true' ) {
            echo  '<form action="" method="POST" id="save_event_wid_form_' . $k . '">' ;
            echo  '<br>' ;
            echo  '<table class="widefat fixed striped" ><thead><tr><th>' ;
            \esc_html_e( 'Field', 'events-optimizer' );
            echo  '</th><th>' ;
            \esc_html_e( 'Value', 'events-optimizer' );
            echo  '</th><th>' ;
            \esc_html_e( 'Status', 'events-optimizer' );
            echo  '</th></tr></thead><tbody>' ;
            foreach ( $fields_arr as $field => $fieldname ) {
                $value = $event_details[$field][0];
                switch ( $field ) {
                    case 'ID':
                        echo  '<tr><td>' . $fieldname . '</td><td><input type="hidden" name="' . $field . '" id="' . $field . '" value="' . $value . '"/><a href="/wp-admin/post.php?post=' . $event[$k]->ID . '&action=edit" target="_blank">' . $value . ' <img src="' . plugin_dir_url( __FILE__ ) . 'images/external-link.png" class="external-link-icon" alt="External Link"/></a>' ;
                        echo  '<a href="https://www.google.com/search?q=' . urlencode( $event[$k]->post_title . ' ' . $event_details['_EventStartDate'][0] ) . '" target="_blank">&nbsp;&nbsp;&nbsp;' ;
                        \esc_html_e( 'Search with Google for it', 'events-optimizer' );
                        echo  ' <img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a>' ;
                        echo  '</td><td>--</td></tr>' ;
                        break;
                    case 'post_content':
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><textarea name="' . $field . '" id="' . $field . '" rows="8" cols="30"></textarea></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $ignored_field_event_description === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><textarea name="' . $field . '" id="' . $field . '" rows="8" cols="30">' . esc_textarea( $value ) . '</textarea></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                    case '_EventStartDate':
                    case '_EventEndDate':
                        if ( $field === '_EventEndDate' and $value === '' ) {
                            $value = $event_details['_EventStartDate'][0];
                        }
                        
                        if ( $field === '_EventEndDate' and $value === $event_details['_EventStartDate'][0] ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . date_format( date_create( $value ), "Y-m-d H:i" ) . '" class="flexible-textfield"/></td><td><span class="field-status-warning">' . __( 'End is equal with start. Please check!', 'events-optimizer' ) . '</span></td></tr>' ;
                            break;
                        }
                        
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . date_format( date_create( $value ), "Y-m-d H:i" ) . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $field === '_EventStartDate' and $ignored_field_event_start === 'false' ) {
                                $found_error = true;
                            }
                            if ( $field === '_EventEndDate' and $ignored_field_event_end === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . date_format( date_create( $value ), "Y-m-d H:i" ) . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                    case '_EventVenueID':
                        $venues_list = '<select name="_EventVenueID">';
                        $venue_found = false;
                        foreach ( $venues_arr as $venue ) {
                            
                            if ( intval( $value ) === intval( $venue['ID'] ) ) {
                                $venues_list .= '<option value="' . $venue['ID'] . '" selected>' . $venue['Name'] . '</option>';
                                $venue_found = true;
                            } else {
                                $venues_list .= '<option value="' . $venue['ID'] . '">' . $venue['Name'] . '</option>';
                            }
                        
                        }
                        
                        if ( $venue_found ) {
                            $venues_list .= '</select>';
                            echo  '<tr><td>' . $fieldname . '</td><td>' . $venues_list . '</td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        } else {
                            $venues_list .= '<option value="" selected>--</option>';
                            $venues_list .= '</select>';
                            echo  '<tr><td>' . $fieldname . '</td><td>' . $venues_list . '</td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $ignored_field_event_venue === 'false' ) {
                                $found_error = true;
                            }
                        }
                        
                        break;
                    case '_EventOrganizerID':
                        $organizers_list = '<select name="_EventOrganizerID">';
                        $organizer_found = false;
                        foreach ( $organizers_arr as $organizer ) {
                            
                            if ( intval( $value ) === intval( $organizer['ID'] ) ) {
                                $organizers_list .= '<option value="' . $organizer['ID'] . '" selected>' . $organizer['Name'] . '</option>';
                                $organizer_found = true;
                            } else {
                                $organizers_list .= '<option value="' . $organizer['ID'] . '">' . $organizer['Name'] . '</option>';
                            }
                        
                        }
                        
                        if ( $organizer_found ) {
                            $organizers_list .= '</select>';
                            echo  '<tr><td>' . $fieldname . '</td><td>' . $organizers_list . '</td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        } else {
                            $organizers_list .= '<option value="" selected>--</option>';
                            $organizers_list .= '</select>';
                            echo  '<tr><td>' . $fieldname . '</td><td>' . $organizers_list . '</td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $ignored_field_event_organizer === 'false' ) {
                                $found_error = true;
                            }
                        }
                        
                        break;
                    case '_EventURL':
                        $valid = url_valid( $value );
                        
                        if ( $valid != '' ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="https://www.google.de/search?q=' . $event_details['post_title'][0] . '" target="_blank"> <img src="' . plugin_dir_url( __FILE__ ) . 'images/search.svg" class="search-icon" alt="Search"/></a></td><td><span class="field-status-error">' . $valid . '</td></tr>' ;
                            if ( $ignored_field_event_website === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/> <a href="' . $value . '" target="_blank"><img src="' . plugin_dir_url( __FILE__ ) . 'images/external-link.png" class="external-link-icon" alt="External Link"/></a></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                        // Check if currency symbol is in custom currency symbol list
                    // Check if currency symbol is in custom currency symbol list
                    case '_EventCurrencySymbol':
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $ignored_field_event_currency_symbol === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            // Custom currency symbols available?
                            
                            if ( !empty($currency_symbols_arr) ) {
                                
                                if ( !in_array( $value, $currency_symbols_arr ) ) {
                                    echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Currency symbol is not in custom currency symbol list', 'events-optimizer' ) . '</span></td></tr>' ;
                                    if ( $ignored_field_event_currency_symbol === 'false' ) {
                                        $found_error = true;
                                    }
                                } else {
                                    echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                                }
                            
                            } else {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                            }
                        
                        }
                        
                        break;
                    case '_EventCost':
                        
                        if ( !is_numeric( $value ) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Field contains invalid characters or is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $ignored_field_event_cost === 'false' ) {
                                $found_error = true;
                            }
                        } else {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                        }
                        
                        break;
                        /*
                        					case '_thumbnail_id':
                        						if ( empty( $value )) {
                        							echo '<tr><td>'. $fieldname. '</td><td>-- <a href="/wp-admin/post.php?post='.$event[$k]->ID.'&action=edit" target="_blank"><img src="'.wp_get_attachment_image_url($value, 'thumbnail').'"><img src="'.plugin_dir_url( __FILE__ ).'images/external-link.png" class="external-link-icon" alt="External Link"/></a></td><td><span class="field-status-error">'.__( 'Field is empty', 'events-optimizer' ).'</span></td></tr>';
                        							$found_error = true;						
                        						} else {					
                        							echo '<tr><td>'. $fieldname. '</td><td><a href="/wp-admin/post.php?post='.$event[$k]->ID.'&action=edit" target="_blank"><img src="'.wp_get_attachment_image_url($value, 'thumbnail').'"> <img src="'.plugin_dir_url( __FILE__ ).'images/external-link.png" class="external-link-icon" alt="External Link"/></a></td><td><span class="field-status-ok">'.__( 'OK', 'events-optimizer' ).'</span></td></tr>';
                        						}
                        						break;
                        */
                    /*
                    					case '_thumbnail_id':
                    						if ( empty( $value )) {
                    							echo '<tr><td>'. $fieldname. '</td><td>-- <a href="/wp-admin/post.php?post='.$event[$k]->ID.'&action=edit" target="_blank"><img src="'.wp_get_attachment_image_url($value, 'thumbnail').'"><img src="'.plugin_dir_url( __FILE__ ).'images/external-link.png" class="external-link-icon" alt="External Link"/></a></td><td><span class="field-status-error">'.__( 'Field is empty', 'events-optimizer' ).'</span></td></tr>';
                    							$found_error = true;						
                    						} else {					
                    							echo '<tr><td>'. $fieldname. '</td><td><a href="/wp-admin/post.php?post='.$event[$k]->ID.'&action=edit" target="_blank"><img src="'.wp_get_attachment_image_url($value, 'thumbnail').'"> <img src="'.plugin_dir_url( __FILE__ ).'images/external-link.png" class="external-link-icon" alt="External Link"/></a></td><td><span class="field-status-ok">'.__( 'OK', 'events-optimizer' ).'</span></td></tr>';
                    						}
                    						break;
                    */
                    default:
                        
                        if ( empty($value) ) {
                            echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-error">' . __( 'Field is empty', 'events-optimizer' ) . '</span></td></tr>' ;
                            if ( $field === 'post_title' ) {
                                $found_error = true;
                            }
                        } else {
                            
                            if ( strlen( $value ) <= 4 ) {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-warning">' . __( 'Field content is very short', 'events-optimizer' ) . '</span></td></tr>' ;
                                if ( $field === 'post_title' ) {
                                    $found_error = true;
                                }
                            } else {
                                echo  '<tr><td>' . $fieldname . '</td><td><input type="text" name="' . $field . '" id="' . $field . '" value="' . $value . '" class="flexible-textfield"/></td><td><span class="field-status-ok">' . __( 'OK', 'events-optimizer' ) . '</span></td></tr>' ;
                            }
                        
                        }
                
                }
                // end switch
            }
            // end foreach
            echo  '</tbody>
				</table>	
				<p><input type="button" name="action" class="button button-primary" id="save_event_button_' . $k . '" value="' . __( 'Save changes', 'events-optimizer' ) . '" onclick="save_form(' . "'" . $k . "'" . ');" />
				&nbsp;&nbsp;&nbsp;<input type="button" name="action" class="button delete" id="ignore_object_button_' . $k . '" value="' . __( 'Ignore', 'events-optimizer' ) . '" onclick="ignore_object(' . "'" . $k . "'" . ');"' ;
            echo  "disabled" ;
            echo  '/>
				</p><div id="status_save_event_wid_' . $k . '">' . __( 'SAVING', 'events-optimizer' ) . '</div></p><br>
				</form>' ;
        }
        
        // end if array_search(
        $nonce = wp_create_nonce( 'events-optimizer-nonce' );
        ?>	

		<script  type='text/javascript'>
	
			function save_form(form_id){
				var datastring = jQuery("#save_event_wid_form_"+form_id).serialize(); 
				jQuery("#save_event_wid_button_"+form_id).attr("disabled", true); // Disable button while saving
				jQuery.ajax({
					type: "post",
					url: "admin-ajax.php",
					data: { 
						action: 'save_eve',
						_ajax_nonce: '<?php 
        echo  $nonce ;
        ?>' ,
						data: datastring,
					},
					beforeSend: function() {
						jQuery("#status_save_event_wid_"+form_id).fadeIn('fast');  // Fade in status when button is clicked
					},
					success: function(html) {
						jQuery("#status_save_event_wid_"+form_id).fadeOut('slow');	// Fade out status after data is saved
						jQuery("#save_event_wid_button_"+form_id).attr("disabled", false); // Enable button after saving
						jQuery("#save_event_wid_form_"+form_id).slideUp(); // Slide organizer form away after saving									
					}
				}); //close jQuery.ajax
				return false;	
			}
			function ignore_object(form_id){
				var datastring = jQuery("#save_event_wid_form_"+form_id).serialize() + '&type=tribe_events&status=ignored';
				jQuery("#ignore_object_button_"+form_id).attr("disabled", true); // Disable button while ignoring
				jQuery.ajax({
					type: "post",
					url: "admin-ajax.php",
					data: { 
						action: 'add_obj',
						_ajax_nonce: '<?php 
        echo  $nonce ;
        ?>' ,
						data: datastring,
					},
					beforeSend: function() {
					},
					success: function(html) {
						jQuery("#status_save_event_wid_"+form_id).fadeOut('slow');	// Fade out status after data is ignored
						jQuery("#ignore_object_button_"+form_id).attr("disabled", false); // Enable button after ignoring
						jQuery("#save_event_wid_form_"+form_id).slideUp(); // Slide venue form away after ignoring							
					}
				}); //close jQuery.ajax
				return false;	
			}						
		</script>	

		<style type='text/css'>
			#status_save_event_wid_<?php 
        echo  $k ;
        ?> { 
				display: none;
				clear: both;
				background: url(images/loading.gif) left top no-repeat; 
				text-align: left;
				padding: 0px 0px 30px 25px; 
			}
			<?php 
        if ( $found_error === false ) {
            echo  "#save_event_wid_form_" . $k . ", #save_event_wid_button_" . $k . " { display: none; }" ;
        }
        ?>	
		</style>

		<?php 
        // if invalid data is found increase counter for maximum results per page
        if ( $found_error === true ) {
            $i++;
        }
        $k++;
    }
    // end while
    
    if ( $k < $max_events ) {
        echo  '<div id="additional_results_events_wid_' . $k . '"<p><strong>' . __( 'Additional results available.', 'events-optimizer' ) . '</strong></p></div>' ;
        echo  '<p><input type="submit" name="action" class="button button-primary" id="show_more_events_wid_button_' . $k . '" value="' . __( 'Show more', 'events-optimizer' ) . '" onclick="show_more(' . "'" . $k . "'" . ');" /></p>' ;
        echo  '<div id="show_more_events_wid"></div>' ;
        echo  '<div id="status_show_more_events_wid_' . $k . '">' . __( 'ANALYZING', 'events-optimizer' ) . '</div>' ;
    } else {
        echo  '<span class="field-status-ok">' . __( 'No (more) results found!', 'events-optimizer' ) . '</span>' ;
    }
    
    $nonce = wp_create_nonce( 'events-optimizer-nonce' );
    ?>	
		
	<script  type='text/javascript'>
	
		function show_more(form_id){
       		jQuery("#show_more_events_wid_button_"+form_id).fadeOut('slow'); // Hide button after  		
    		jQuery("#show_more_events_wid_button_"+form_id).attr("disabled", true); // Disable button while retrieving more results
    		jQuery.ajax({
				type: "post",
				url: "admin-ajax.php",
				data: { 
					action: 'events_wid',
					next_result: form_id,
					_ajax_nonce: '<?php 
    echo  $nonce ;
    ?>' 
				},
				beforeSend: function() {
					jQuery("#status_show_more_events_wid_"+form_id).fadeIn('fast');  // Fade in status when button is clicked
					jQuery("#additional_results_events_wid_"+form_id).fadeOut('slow');	// Fade out text "Additional results ..." after data is saved
				},
				success: function(html) {
					jQuery("#show_more_events_wid_button_"+form_id).attr("disabled", false); // Enable button after
					jQuery("#status_show_more_events_wid_"+form_id).fadeOut('slow');	// Fade out status after data is saved
					jQuery("#show_more_events_wid").append(html); // Add the additional results to page
				}
    		}); //close jQuery.ajax
    		return false;	
    	}	
	</script>

	<style type='text/css'>
		#status_show_more_events_wid_<?php 
    echo  $k ;
    ?> { 
			display: none;
			clear: both;
			background: url(images/loading.gif) left top no-repeat; 
			text-align: left;
			padding: 0px 0px 30px 25px; 
		}
	</style>

	<?php 
    die;
}

//----------------------------------------------------------------------------------------
// Save event data (for events with invalid data)
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_save_eve', 'save_event' );
function save_event()
{
    check_ajax_referer( 'events-optimizer-nonce' );
    parse_str( $_POST['data'], $event );
    // Title and description can't be updated directly with the TEC API (empty fields gets ignored - bug?) and therefore it needs to be updated seperatly
    $event_post_arr = array(
        'ID'           => $event['ID'],
        'post_title'   => sanitize_text_field( $event['post_title'] ),
        'post_content' => sanitize_textarea_field( $event['post_content'] ),
    );
    wp_update_post( $event_post_arr );
    // Update event with additional values
    $event_arr = array(
        'EventStartDate'      => substr( $event['_EventStartDate'], 0, 10 ),
        'EventEndDate'        => substr( $event['_EventEndDate'], 0, 10 ),
        'EventStartHour'      => substr( $event['_EventStartDate'], 11, 2 ),
        'EventEndHour'        => substr( $event['_EventEndDate'], 11, 2 ),
        'EventStartMinute'    => substr( $event['_EventStartDate'], 14, 2 ),
        'EventEndMinute'      => substr( $event['_EventEndDate'], 14, 2 ),
        'Venue'               => array(
        'VenueID' => sanitize_text_field( $event['_EventVenueID'] ),
    ),
        'Organizer'           => array(
        'OrganizerID' => sanitize_text_field( $event['_EventOrganizerID'] ),
    ),
        'EventURL'            => sanitize_text_field( $event['_EventURL'] ),
        'EventCost'           => sanitize_text_field( $event['_EventCost'] ),
        'EventCurrencySymbol' => sanitize_text_field( $event['_EventCurrencySymbol'] ),
    );
    //	'FeaturedImage'			=> sanitize_text_field( $event[ '_thumbnail_id' ] )
    tribe_update_event( $event['ID'], $event_arr );
    die;
}

//----------------------------------------------------------------------------------------
// Search Events from Google data
// Creates a task with the results at DataForSEO
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_search_events_wgd', 'search_events_with_google_data' );
function search_events_with_google_data()
{
}

//----------------------------------------------------------------------------------------
// Show search results and add events from DataForSEO (Google events data)
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_add_events_wgd', 'add_events_with_google_data' );
function add_events_with_google_data()
{
}

//----------------------------------------------------------------------------------------
// Add event with Google Events
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_add_eve', 'add_event' );
function add_event()
{
}

//----------------------------------------------------------------------------------------
// Add object to list of added and ignored objects in WordPress options
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_add_obj', 'add_object' );
function add_object()
{
}

//----------------------------------------------------------------------------------------
// Remove duplicate objects from list of added and ignored objects
// https://stackoverflow.com/questions/307674/how-to-remove-duplicate-values-from-a-multi-dimensional-array-in-php
//----------------------------------------------------------------------------------------
// Buggy!!!
function remove_duplicates( $array, $key )
{
}

//----------------------------------------------------------------------------------------
// Remove object from list of added and ignored objects
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_remove_obj', 'remove_object' );
function remove_object()
{
}

//----------------------------------------------------------------------------------------
// Reset list of added or ignored objects
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_reset_object_li', 'reset_object_list' );
function reset_object_list()
{
}

//----------------------------------------------------------------------------------------
// Save settings
//----------------------------------------------------------------------------------------
add_action( 'wp_ajax_save_set', 'save_settings' );
function save_settings()
{
    check_ajax_referer( 'events-optimizer-nonce' );
    $max_results_per_page = urldecode( $_POST['max_results_per_page'] );
    if ( $max_results_per_page > 20 ) {
        $max_results_per_page = 20;
    }
    update_option( 'teo_max_results_per_page', $max_results_per_page );
    die;
}

//----------------------------------------------------------------------------------------
// Google Place API: Place text search
// https://medium.com/@pauljkbs/simple-way-to-get-started-with-the-google-places-api-and-php-9a1f55f8919e
//----------------------------------------------------------------------------------------
function google_places_text_search( $query = '' )
{
}

//----------------------------------------------------------------------------------------
// Google Place API: Place details with place_id
//----------------------------------------------------------------------------------------
function get_place_details( $place_id = '' )
{
}

//----------------------------------------------------------------------------------------
// Google Place API: Place details with cid
// Possible Enhancement:
// https://developers.google.com/maps/documentation/places/web-service/place-id#save-id
//----------------------------------------------------------------------------------------
function get_place_details_cid( $cid = '' )
{
}

//----------------------------------------------------------------------------------------
// Check if URL is valid and reachable
//----------------------------------------------------------------------------------------
function url_valid( $url = true )
{
    // Check URLs with Google Safe Browsing
    $google_safe_browsing = get_option( 'teo_google_safe_browsing', 'false' );
    $validate_url_https = get_option( 'teo_validate_url_https', 'false' );
    $validate_url_redirected_moved = get_option( 'teo_validate_url_redirected_moved', 'false' );
    // If URL contains something check what's inside
    
    if ( !empty($url) ) {
        // Is URL syntax valid? Accept as ok, even when http:// or https:// or www is missing
        $url = filter_var( $url, FILTER_SANITIZE_URL );
        // Check on missing https / http
        
        if ( $validate_url_https === 'false' ) {
            $valid_urls = array( $url, 'http://' . $url, 'https://' . $url );
        } else {
            $valid_urls = array( $url, 'http://www' . $url, 'https://www' . $url );
        }
        
        foreach ( $valid_urls as $valid_url ) {
            // Check if URL syntax is valid
            
            if ( filter_var( $valid_url, FILTER_VALIDATE_URL ) ) {
                // Check if website is reachable as well
                unset( $file_headers );
                $file_headers = @get_headers( $valid_url );
                // Check if URL is redirected or permanently moved
                if ( teo_fs()->can_use_premium_code__premium_only() and $validate_url_redirected_moved === 'true' ) {
                    if ( strpos( $file_headers[0], '301' ) > 0 or strpos( $file_headers[0], '302' ) > 0 ) {
                        return __( 'URL is redirected or moved permanently', 'events-optimizer' );
                    }
                }
                
                if ( $file_headers || $file_headers[0] != 'HTTP/1.1 404 Not Found' and !empty($file_headers || $file_headers[0]) ) {
                    // Activate only for Pro version
                    
                    if ( teo_fs()->can_use_premium_code__premium_only() and $google_safe_browsing === 'true' ) {
                        // Check if URL is marked as suspicous by Google
                        $googleSafebrowsing = new GoogleSafebrowsing();
                        $status = $googleSafebrowsing->check( $valid_url );
                        
                        if ( $status === GoogleSafebrowsing::OK ) {
                            // URL is valid
                            return '';
                        } else {
                            return __( 'Google says this URL is suspicious! Please check!', 'events-optimizer' );
                        }
                    
                    } else {
                        // URL is valid
                        return '';
                    }
                
                } else {
                    return __( 'URL is not reachable', 'events-optimizer' );
                }
            
            } else {
                return __( 'URL syntax is not valid', 'events-optimizer' );
            }
        
        }
        // end foreach
        // URL is empty
    } else {
        return __( 'Field is empty', 'events-optimizer' );
    }

}

//----------------------------------------------------------------------------------------
// Check if URL is marked as suspicious by Google Safe Browsing
// https://transparencyreport.google.com/safe-browsing/search?url
//----------------------------------------------------------------------------------------
class GoogleSafebrowsing
{
    const  OK = 0 ;
    const  SUSPICIOUS = 201 ;
    const  ENDPOINT = "https://www.google.com/safebrowsing/diagnostic?output=jsonp&site=" ;
    /**
     * @param string $url
     *
     * @return integer
     */
    public function check( $url )
    {
        if ( filter_var( $url, FILTER_VALIDATE_URL ) === false ) {
            throw new \Exception( "Invalid URL" );
        }
        $safebrowsing = @file_get_contents( self::ENDPOINT . $url );
        if ( strpos( $safebrowsing, '"listed"' ) ) {
            return self::SUSPICIOUS;
        }
        return self::OK;
    }

}
//----------------------------------------------------------------------------------------
// Check if mail address is valid
//----------------------------------------------------------------------------------------
function mail_valid( $mail = true )
{
    // If mail contains something check what's inside
    
    if ( !empty($mail) ) {
        // Is mail syntax valid?
        if ( !filter_var( $mail, FILTER_VALIDATE_EMAIL ) ) {
            return __( 'Mail is not valid', 'events-optimizer' );
        }
        // Mail is empty
    } else {
        return __( 'Mail is empty!', 'events-optimizer' );
    }

}

//----------------------------------------------------------------------------------------
// Create clean URL for SEO
// https://stackoverflow.com/questions/4783802/converting-string-into-web-safe-uri
//----------------------------------------------------------------------------------------
function get_clean_url( $str, $replace = array(), $delimiter = '-' )
{
    setlocale( LC_ALL, 'en_US.UTF8' );
    if ( !empty($replace) ) {
        $str = str_replace( (array) $replace, ' ', $str );
    }
    $clean = iconv( 'UTF-8', 'ASCII//TRANSLIT', $str );
    $clean = preg_replace( "/[^a-zA-Z0-9\\/_|+ -]/", '', $clean );
    $clean = strtolower( trim( $clean, '-' ) );
    $clean = preg_replace( "/[\\/_|+ -]+/", $delimiter, $clean );
    return $clean;
}

//----------------------------------------------------------------------------------------
// Count elements in array with specific key
// https://stackoverflow.com/questions/11558397/count-specific-values-in-multidimensional-array/11558780
//----------------------------------------------------------------------------------------
function array_count_key( $array, $find )
{
    $i = 0;
    foreach ( $array as $key => $value ) {
        if ( $value['type'] === $find ) {
            $i++;
        }
    }
    return $i;
}

//----------------------------------------------------------------------------------------
// Write debugging info to console
// https://wordpress.org/plugins/wp-debugging/
//----------------------------------------------------------------------------------------
function write_to_console( $data )
{
    $output = $data;
    if ( is_array( $output ) ) {
        $output = implode( ',', $output );
    }
    echo  "<script>console.log('Debug Objects: " . $output . "' );</script>" ;
}
